#
# spec file for package NetworkManager
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Use systemd
%define with_systemd 1
%define with_wimax 0
# Toggle this whenever enabling/disabling the nm-probe-radius-server-cert.patch patch (as we export additional symbols)
# Like this, g-c-c and NM-applet, which consume this symbol, will block updating NM if we have to disable the patch until
# they are touched too
%define with_cacert_patch 1

Name:           NetworkManager
Url:            http://www.gnome.org/projects/NetworkManager/
Version:        1.0.12
Release:        7.3.1
Summary:        Network Link Manager and User Applications
License:        GPL-2.0+
Group:          Productivity/Networking/System
Source0:        http://download.gnome.org/sources/NetworkManager/1.0/%{name}-%{version}.tar.xz
Source1:        nfs
Source2:        NetworkManager.conf
Source3:        baselibs.conf
Source99:       NetworkManager-rpmlintrc
# PATCH-FEATURE-OPENSUSE systemd-network-config.patch -- don't try to start NM under systemd if it is disabled in system configuration
Patch0:         systemd-network-config.patch
# PATCH-HACK-OPENSUSE nm-don-t-consider-not-needed-secrets-for-has_system_secr.diff lnussel@suse.com -- avoid polkit popups for 802.11x
Patch3:         nm-don-t-consider-not-needed-secrets-for-has_system_secr.diff
# PATCH-HACK-OPENSUSE nm-treat-not-saved-secrets-just-like-agent-owned-when-cl.diff lnussel@suse.com -- avoid polkit popups for 802.11x
Patch4:         nm-treat-not-saved-secrets-just-like-agent-owned-when-cl.diff
# PATCH-FIX-UPSTREAM nm-probe-radius-server-cert.patch bnc#574266 glin@suse.com -- Probe the RADIUS server certificate
Patch5:         nm-probe-radius-server-cert.patch
# PATCH-FIX-OPENSUSE NetworkManager-geoclue-interaction.patch dimstar@opensuse.org -- Allow the user "srvGeoClue" to query NetworkManager on the dbus
Patch6:         NetworkManager-geoclue-interaction.patch
# PATCH-FIX-UPSTREAM nm-fix-always-prompt-for-new-password.patch bsc#966232 sckang@suse.com -- Don't always prompt for new password when supplicant fails in 4-way handshake
Patch7:         nm-fix-always-prompt-for-new-password.patch
# PATCH-FIX-OPENSUSE nm-dont-crash-when-system-secret-is-not-needed.patch bsc#1009717 sckang@suse.com -- Fix NM crash when editing the same wifi settings for the second time
Patch8:         nm-dont-crash-when-system-secret-is-not-needed.patch
# PATCH-FIX-OPENSUSE nm-dont-overwrite-resolv-conf.patch bsc#1021665, bsc#960153 sckang@suse.com -- NetworkManager spawns netconfig to update DNS settings, and terminates netconfig after 1s. But 1s isn't quite long enough for netconfig to complete the task. Adjust it to 0 seconds(don't send SIGKILL) to avoid NM overwriting /etc/resolv.conf.
Patch9:         nm-dont-overwrite-resolv-conf.patch
# PATCH-FIX-OPENSUSE nm-fix-dhcp-client-timeout.patch bsc#1103477 sckang@suse.com -- Fix NetworkManager ignoring valid leases on dhcp timeout
Patch10:        nm-fix-dhcp-client-timeout.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  iptables
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  ppp-devel
BuildRequires:  readline-devel
BuildRequires:  rp-pppoe
# Do not use suse-release, it's very late in build chain and not needed
# all it does is netconfig and ifconfig enablement
#BuildRequires:  suse-release
# for /sbin/netconfig: integration with netconfig is required
BuildRequires:  sysconfig
BuildRequires:  translation-update-upstream
BuildRequires:  vala
BuildRequires:  wireless-tools
BuildRequires:  pkgconfig(bluez) >= 5
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.94
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libnewt) >= 0.52.15
%if %{with_wimax}
BuildRequires:  pkgconfig(libiWmxSdk-0) >= 1.5.1
%endif
BuildRequires:  pkgconfig(libndp)
BuildRequires:  pkgconfig(libnl-3.0) >= 3.2.8
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(libnl-route-3.0)
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.40
%if %{with_systemd}
BuildRequires:  pkgconfig(libsystemd) >= 209
%endif
BuildRequires:  pkgconfig(libteam)
BuildRequires:  pkgconfig(mm-glib) >= 0.7.991
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(polkit-agent-1) >= 0.97
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(uuid)
Requires:       NetworkManager-branding
Requires:       dhcp-client
Requires:       iproute2
Requires:       iputils
Requires:       mozilla-nss
Requires:       sysconfig >= 0.80.5
Requires:       wpa_supplicant >= 0.6.4
%requires_eq    ppp
%{?systemd_requires}
Provides:       dhcdbd = 1.14
Obsoletes:      dhcdbd < 1.14
Recommends:     dnsmasq
Recommends:     iptables
Recommends:     NetworkManager-client
Recommends:     org.freedesktop.ModemManager
Recommends:     avahi-autoipd
# Recommend the rp-pppoe binary for PPP over Ethernet (common for ADSL) connections.
Recommends:     rp-pppoe
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define _udevdir %(pkg-config --variable udevdir udev)

%description
NetworkManager attempts to keep an active network connection available
at all times.  The point of NetworkManager is to make networking
configuration and setup as painless and automatic as possible.	If
using DHCP, NetworkManager is intended to replace default routes,
obtain IP addresses from a DHCP server, and change name servers
whenever it sees fit.

%if %{with_wimax}
%package device-plugin-wimax
Summary:        WiMAX support for NetworkManager
Group:          Productivity/Networking/System
Supplements:    %{name}

%description device-plugin-wimax
NetworkManager attempts to keep an active network connection available
at all times.  The point of NetworkManager is to make networking
configuration and setup as painless and automatic as possible.	If
using DHCP, NetworkManager is intended to replace default routes,
obtain IP addresses from a DHCP server, and change name servers
whenever it sees fit.
%endif

%package devel
Summary:        Libraries and headers for adding NetworkManager support to applications
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       libnm-glib-vpn1 = %{version}
Requires:       libnm-glib4 = %{version}
Requires:       libnm-util2 = %{version}
Requires:       libnm0 = %{version}
Requires:       typelib-1_0-NM-1_0 = %{version}
Requires:       typelib-1_0-NMClient-1_0 = %{version}
Requires:       typelib-1_0-NetworkManager-1_0 = %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description devel
This package contains various headers accessing some NetworkManager
functionality from applications.

%package -n libnm0
Summary:        Convenience library for clients of NetworkManager
Group:          System/Libraries

%description -n libnm0
This package contains the libraries that make it easier to use some
Network Manager functionality from applications that use glib.

%package -n libnm-util2
Summary:        Convenience library for clients of NetworkManager
Group:          System/Libraries
%if %{with_cacert_patch}
Provides:       NetworkManager(cacert-patch)
%endif

%description -n libnm-util2
This package contains the libraries that make it easier to use some
Network Manager functionality from applications that use glib.

%package -n libnm-glib4
Summary:        Convenience library for clients of NetworkManager
Group:          System/Libraries
Provides:       %{name}-glib = %{version}
Obsoletes:      %{name}-glib < %{version}

%description -n libnm-glib4
This package contains the libraries that make it easier to use some
Network Manager functionality from applications that use glib.

%package -n libnm-glib-vpn1
Summary:        Convenience library for NetworkManager VPN plugins
Group:          System/Libraries

%description -n libnm-glib-vpn1
This package contains the libraries that make it easier to use some
Network Manager functionality from applications that use glib.

%package -n typelib-1_0-NetworkManager-1_0
Summary:        Convenience library for clients of NetworkManager -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-NetworkManager-1_0
This package contains the gi-bindings that make it easier to use some
Network Manager functionality from applications that use glib.

This package provides the GObject Introspection bindings for the
NetworkManager library.

%package -n typelib-1_0-NM-1_0
Summary:        Convenience library for clients of NetworkManager -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-NM-1_0
This package contains the gi-bindings that make it easier to use some
Network Manager functionality from applications that use glib.

This package provides the GObject Introspection bindings for the
NetworkManager library.

%package -n typelib-1_0-NMClient-1_0
Summary:        Convenience library for clients of NetworkManager -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-NMClient-1_0
This package contains the gi-bindings that make it easier to use some
Network Manager functionality from applications that use glib.

This package provides the GObject Introspection bindings for the
NetworkManager library.

%package branding-upstream
Summary:        Default upstream configuration for /etc/NetworkManager/NetworkManager.conf
Group:          Productivity/Networking/System
Requires:       NetworkManager = %{version}
Provides:       NetworkManager-branding = %{version}
Conflicts:      otherproviders(NetworkManager-branding)
Supplements:    packageand(NetworkManager:branding-upstream)
BuildArch:      noarch

%description branding-upstream
This package provides the default upstream configuration for
%{_sysconfdir}/NetworkManager/NetworkManager.conf. Specifically,
it is not configured for connection checking against
http://conncheck.opensuse.org. For, the version with connection
checking, install %{name}-branding-openSUSE.

%lang_package
%prep
%setup -n %{name}-%{version} -q
translation-update-upstream
%patch0 -p1
%patch3 -p1
%patch4 -p1
%if %{with_cacert_patch}
%patch5 -p1
%endif
%patch6 -p1
%patch7 -p1
%if 0%{?suse_version} == 1315
%patch8 -p1
%patch9 -p1
%endif
%patch10 -p1

%build
pppddir=`ls -1d /usr/%_lib/pppd/2*`
test -n "$pppddir" || exit 1
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure\
    --disable-static\
    --with-crypto=nss \
    --enable-ifcfg-suse \
    --with-docs\
    --with-netconfig=yes \
    --enable-more-warnings=no \
    --with-pppd-plugin-dir=$pppddir \
    --with-dhclient=/sbin/dhclient \
    --with-udev-dir=%{_udevdir} \
    --with-modem-manager-1 \
    --enable-concheck \
    --with-nmtui \
%if %{with_systemd}
    --with-session-tracking=systemd \
%endif
%if %{with_wimax}
    --enable-wimax
%else
    --disable-wimax
%endif
# Fail if netconfig was not detected. Avoids future occurences of bnc#817592
if grep "with_netconfig='no'" config.log; then
  print netconfig support was not found -- BUILD ABORTED
  false
fi
%__make %{?_smp_mflags} nmrundir="/run/%{name}"

%install
%makeinstall nmrundir="/run/%{name}"
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/gtk-doc/
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/VPN
mkdir -p $RPM_BUILD_ROOT/var/log/
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/NetworkManager
touch $RPM_BUILD_ROOT/var/log/NetworkManager
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/system-connections
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/dispatcher.d/
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/
# We package this one as %doc in the default location.
rm %{buildroot}/usr/share/doc/NetworkManager/examples/server.conf

%if 0%{suse_version} > 1140
# drop on demand activation, it is handled as a system service
rm -f $RPM_BUILD_ROOT%{_datadir}/dbus-1/system-services/org.freedesktop.NetworkManager.service

%pre
%service_add_pre NetworkManager.service
%service_add_pre NetworkManager-dispatcher.service

%post
%service_add_post NetworkManager.service
%service_add_post NetworkManager-dispatcher.service
# enable NetworkManager-dispatcher, it's a DBus enabled service
systemctl enable NetworkManager-dispatcher.service
# bnc#803058:
# sysconfig creates this file while update from openSUSE < 12.3,
# which were using the NETWORKMANAGER=yes/no sysconfig variable.
# When it exists and NETWORKMANAGER were enabled, force enable to
# ensure, the network.service alias link exists points to us.
if [ -f /dev/.sysconfig/network/migrate_nm_variable ] ; then
	. /dev/.sysconfig/network/migrate_nm_variable
	if [ "X$NETWORKMANAGER" = "Xyes" ] ; then
		# In running system "--force enable" is sufficient to
		# create the network.service alias link regardless if
		# the network.service is masked or not.
		# While 12.2 -> 12.3 dist update, enable seems to be
		# unable to create the alias... no idea why. Kick it
		rm -f /etc/systemd/system/network.service
		/usr/bin/systemctl --system daemon-reload || :
		/usr/bin/systemctl --force enable NetworkManager.service || :
		# and create the alias when enable failed to make it.
		if [ ! -e /etc/systemd/system/network.service ] ; then
			ln -sf	%{_unitdir}/NetworkManager.service \
				/etc/systemd/system/network.service
		fi
		/usr/bin/systemctl --system daemon-reload || :
	fi
	rm -f /dev/.sysconfig/network/migrate_nm_variable
fi

%preun
%service_del_preun NetworkManager.service
%service_del_preun NetworkManager-dispatcher.service

%postun
%service_del_postun NetworkManager.service
%service_del_postun NetworkManager-dispatcher.service
%endif

%post -n libnm-util2 -p /sbin/ldconfig

%postun -n libnm-util2 -p /sbin/ldconfig

%post -n libnm-glib4 -p /sbin/ldconfig

%postun -n libnm-glib4 -p /sbin/ldconfig

%post -n libnm-glib-vpn1 -p /sbin/ldconfig

%postun -n libnm-glib-vpn1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING ChangeLog NEWS AUTHORS README CONTRIBUTING TODO data/server.conf
%{_bindir}/nm-online
%{_bindir}/nmcli
%{_bindir}/nmtui*
%{_datadir}/bash-completion/completions/nmcli
%{_sbindir}/NetworkManager
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_dispatcher.service
%{_datadir}/polkit-1/actions/org.freedesktop.NetworkManager.policy
%attr(0700,root,root) %{_localstatedir}/lib/NetworkManager
%doc %{_mandir}/man1/nm-online.*
%doc %{_mandir}/man1/nmcli.*
%doc %{_mandir}/man1/nmtui.1%{?ext_man}
%doc %{_mandir}/man1/nmtui-connect.1%{?ext_man}
%doc %{_mandir}/man1/nmtui-edit.1%{?ext_man}
%doc %{_mandir}/man1/nmtui-hostname.1%{?ext_man}
%doc %{_mandir}/man5/nm-settings-ifcfg-rh.5%{?ext_man}
%doc %{_mandir}/man5/nm-settings-keyfile.5%{?ext_man}
%doc %{_mandir}/man5/NetworkManager.conf.5%{?ext_man}
%doc %{_mandir}/man5/nm-settings.5%{?ext_man}
%doc %{_mandir}/man5/nm-system-settings.conf.5%{?ext_man}
%doc %{_mandir}/man5/nmcli-examples.5%{?ext_man}
%doc %{_mandir}/man8/NetworkManager.*
%dir %{_libdir}/NetworkManager/
%{_libdir}/NetworkManager/libnm-wwan.so
%{_libdir}/NetworkManager/libnm-settings-plugin-ifcfg-suse.so
%{_libdir}/NetworkManager/libnm-device-plugin-adsl.so
%{_libdir}/NetworkManager/libnm-device-plugin-bluetooth.so
%{_libdir}/NetworkManager/libnm-device-plugin-wifi.so
%{_libdir}/NetworkManager/libnm-device-plugin-wwan.so
%{_libdir}/NetworkManager/libnm-settings-plugin-ibft.so
%{_libdir}/NetworkManager/libnm-device-plugin-team.so
%dir %{_libdir}/pppd/2.*
%{_libdir}/pppd/2.*/nm-pppd-plugin.*
%{_libexecdir}/nm-avahi-autoipd.action
%{_libexecdir}/nm-dhcp-helper
%{_libexecdir}/nm-dispatcher
%{_libexecdir}/nm-iface-helper
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.NetworkManager.conf
%{_sysconfdir}/dbus-1/system.d/nm-avahi-autoipd.conf
%{_sysconfdir}/dbus-1/system.d/nm-dispatcher.conf
%dir %{_sysconfdir}/NetworkManager
%dir %{_sysconfdir}/NetworkManager/VPN
%dir %{_sysconfdir}/NetworkManager/dispatcher.d
%dir %{_sysconfdir}/NetworkManager/system-connections
%attr(0755,root,root) %{_sysconfdir}/NetworkManager/dispatcher.d/nfs
%{_unitdir}/NetworkManager.service
%{_unitdir}/NetworkManager-dispatcher.service
%{_unitdir}/NetworkManager-wait-online.service
%dir %{_unitdir}/network-online.target.wants
%{_unitdir}/network-online.target.wants/NetworkManager-wait-online.service
%{_udevdir}/rules.d/84-nm-drivers.rules
%{_udevdir}/rules.d/85-nm-unmanaged.rules
%ghost %config(noreplace) /var/log/NetworkManager

%if %{with_wimax}
%files device-plugin-wimax
%defattr(-,root,root)
%{_libdir}/NetworkManager/libnm-device-plugin-wimax.so
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/NetworkManager/
%{_includedir}/libnm/
%{_includedir}/libnm-glib/
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libnm-glib.deps
%{_datadir}/vala/vapi/libnm-glib.vapi
%{_datadir}/vala/vapi/libnm-util.deps
%{_datadir}/vala/vapi/libnm-util.vapi
%{_libdir}/libnm.so
%{_libdir}/libnm-util.so
%{_libdir}/libnm-glib.so
%{_libdir}/libnm-glib-vpn.so
%{_libdir}/pkgconfig/NetworkManager.pc
%{_libdir}/pkgconfig/libnm.pc
%{_libdir}/pkgconfig/libnm-util.pc
%{_libdir}/pkgconfig/libnm-glib.pc
%{_libdir}/pkgconfig/libnm-glib-vpn.pc
%doc %{_datadir}/gtk-doc/html/NetworkManager/
%doc %{_datadir}/gtk-doc/html/libnm/
%doc %{_datadir}/gtk-doc/html/libnm-glib/
%doc %{_datadir}/gtk-doc/html/libnm-util/

%files -n libnm0
%defattr(-,root,root)
%{_libdir}/libnm.so.*

%files -n libnm-util2
%defattr(-,root,root)
%{_libdir}/libnm-util.so.*

%files -n libnm-glib4
%defattr(-,root,root)
%{_libdir}/libnm-glib.so.*

%files -n libnm-glib-vpn1
%defattr(-,root,root)
%{_libdir}/libnm-glib-vpn.so.*

%files -n typelib-1_0-NetworkManager-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/NetworkManager-1.0.typelib

%files -n typelib-1_0-NM-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/NM-1.0.typelib

%files -n typelib-1_0-NMClient-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/NMClient-1.0.typelib

%files lang -f %{name}.lang

%files branding-upstream
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/NetworkManager/NetworkManager.conf

%changelog
* Wed Sep 12 2018 sckang@suse.com
- Add nm-fix-dhcp-client-timeout.patch: Fix NetworkManager ignore
  valid leases on dhcp timeout (bsc#1103477).
* Mon Sep 25 2017 sckang@suse.com
- Modify nm-dont-overwrite-resolv-conf.patch: make netconfig call
  an atomic action, don't kill it after 2000ms (bsc#960153).
* Mon Feb 20 2017 sckang@suse.com
- Add nm-dont-overwrite-resolv-conf.patch: Fix NetworkManager
  overwriting /etc/resolv.conf (bsc#960153, bsc#1021665).
* Thu Jan 19 2017 sckang@suse.com
- Add nm-dont-crash-when-system-secret-is-not-needed.patch: Fix
  NetworkManager crashes when editing the same Wifi the second
  time in gnome-control-center (bsc#1009717).
* Mon Dec 19 2016 sckang@suse.com
- Add nm-fix-always-prompt-for-new-password.patch: Don't ask for
  new PSk for locally-generated
  WLAN_REASON_DISASSOC_DUE_TO_INACTIVITY error (bsc#966232).
* Tue Sep 13 2016 sckang@suse.com
- Modify
  nm-don-t-consider-not-needed-secrets-for-has_system_secr.diff:
  Remove two assertions that brings error message (bsc#882801).
* Mon Jul 18 2016 sckang@suse.com
- Modify nm-probe-radius-server-cert.patch: Make sure the "Apply"
  button in Wifi configuration page of gnome-control-center is
  clickable (bsc#985332).
* Mon May 30 2016 fcrozat@suse.com
- Move provides NetworkManager(cacert-patch) to libnm-util2, to
  ensure gnome-control-center doesn't hard requires NetworkManager.
* Fri Apr  8 2016 sckang@suse.com
- Update to version 1.0.12 (FATE#318572)
- drop nm-core-fix-crash-during-Wi-Fi-rescan-by-emitting-NM_DE.patch
  contained in version 0.9.9.1.
- Rebase NetworkManager-geoclue-interaction.patch
- Rebase nm-don-t-consider-not-needed-secrets-for-has_system_secr.diff
- Rebase nm-treat-not-saved-secrets-just-like-agent-owned-when-cl.diff
- Rebase systemd-network-config.patch
- Rebase nm-probe-radius-server-cert.patch
* Tue Apr  5 2016 sckang@suse.com
- nm-treat-not-saved-secrets-just-like-agent-owned-when-cl.diff
  rebased.
* Sat Apr  2 2016 badshah400@gmail.com
  _ Update to version 1.0.12:
  + DHCP leases on software devices are now renewed when the
    computer is awoken from suspend.
  + Improved ifupdown plugin robustness and interoperability on
    Yocto and OpenEmbedded.
  + Fixed failed VPN activations when plugin supports interactive
    mode, but the VPN daemon does not.
  + Wi-Fi monitor interfaces are now ignored, not turned into
    managed mode.
  + AP and AdHoc mode connections with manual IP configuration are
    now able to autoconnect.
  + Broken device drivers (AWS ENI) that initially have invalid
    MAC addresses are now properly managed as soon as correct MAC
    address is set.
  + WWAN devices are unlocked a bit earlier so that supported IP
    versions can be queried.
  + The NetworkManager.service was ordered after
    network-pre.target and dbus.service. This ensures
    NetworkManager doesn't set up connectivity before firewall
    rules are in place and wouldn't exit before remote filesystems
    can be umounted ensuring orderly operation of systemd managed
    installations.
  + The netfilter rules used with shared IPv4 method are now
    removed on exit.
  + Ability to manage USB gadget drivers (UDC side) has beed
    added.
  + Infiniband transport mode change now takes place with the link
    set down because some drivers need that.
  + Race conditions that could disclose connection secrets to
    authenticated local users when changing ifcfg and keyfile
    connections have been fixed.  This has security impact of low
    severity (CVE-2016-0764).
  + A handful of memory leak and crasher bugs of minor importance
    have been fixed.
- Drop patches incorporated upstream:
  - NetworkManager-openvpn-route-configuration.patch.
  - nm-ppp-manager-clear-ppp_watch_id.patch.
  - nm-update-ip_iface-only-if-IP-interface-exists.patch.
- Rebase systemd-network-config.patch for updated version.
* Fri Apr  1 2016 sckang@suse.com
- nm-don-t-consider-not-needed-secrets-for-has_system_secr.diff
  rebased.
* Sun Mar 13 2016 badshah400@gmail.com
- Split out a NetworkManager-branding-upstream subpackage that
  installs the default upstream version of the
  /etc/NetworkManager/NetworkManager.conf file.
- Add Requires: NetworkManager-branding to main package.
* Wed Jan  6 2016 zaitor@opensuse.org
- Add nm-ppp-manager-clear-ppp_watch_id.patch and
  nm-update-ip_iface-only-if-IP-interface-exists.patch: Patches
  from upstream git cherrypicked to stable branch from master.
* Wed Jan  6 2016 dimstar@opensuse.org
- Add NetworkManager-openvpn-route-configuration.patch: Fix routes
  not being applied when connecting to openVPN.
* Sun Jan  3 2016 damjanovic.ivo@gmail.com
- Add explicit pkgconfig(libteam) BuildRequires: force team
  connection support.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 1.0.10:
  + Added support for handling VPN secrets to nmtui and nmcli agent.
  + Fixed a regression that caused NetworkManager to ignore
    external deletion of a device with master.
  + Fixed glitches with older versions of glib (prior to 2.36.0).
  + Fixed build with most recent versions of libsoup.
  + Fixed busy retry loop on non-transient errors from
    wpa_supplicant.
  + Improvements to testing infrastructure.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 1.0.8:
  + MTU indicated by a VPN gateway is now properly applied.
  + Fixed MSS setting when MTU changes.
  + The default route is properly restored on device disconnect.
  + Build with older toolchains has been fixed.
  + The team devices can now properly be enslaved to bridges.
  + Failed DHCP attempts for assumed connections are now retried
    after a timeout.
  + Default wired connection is now created after udev registers
    the device.
  + Support for Bluetooth DUN devices with Bluez 5 has been fixed.
  + The ipv6.ignore-auto-dns property is now properly honored
    making it possible to override automatically obtained name
    servers.
  + Invalid permanent MAC adddresses as reported by some devices
    are now ignored.
  + Device links reported by more recent versions of Linux kernel
    that reside in different network namespaces are no longer
    confused with links in the namespace NetworkManager runs in.
  + MAC address changes of VLANs enslaved to a bond are now
    properly propagated to the master device.
  + Fixed error handling for teaming devices with invalid
    configuration.
  + Wi-Fi AP list is now updated correctly after AP mode has been
    used.
  + Management of a device is not attempted until the device has
    been registered with udev.
  + The error handling for VPN secret agents is now significantly
    more robust.
  + Detection of s390 CTC devices now works properly.
  + A GATEWAY property in /etc/sysconfig/network now no longer
    affects non-static connections.
  + Added support for IPv6-only VPN connections.
  + The systemd service now uses HUP signal to reload
    configuration.
  + Change VLAN default flags to set REORDER_HDR for new
    connections.
  + nmtui is now able to ignore automatically configured routes.
  + Numerous bash shell autocompletion fixes for nmcli.
  + Allow setting IPv6 and PPP settings for GSM and CDMA
    connections via nmcli.
  + Added support for adding ADSL connections in nmcli.
  + Numerous crash fixes.
  + Updated translations.
- Rebase NetworkManager-geoclue-interaction.patch.
* Tue Sep  1 2015 simon@simotek.net
- Update to version 1.0.6:
  + Improved capture portal detection.
  + Default route through WiFi connection is now preferred to
    Mobile Broadband if both are available.
  + Expose a flag to determine whether a particular connection is
    metered via API and client tools.
  + Add support for locking connections to a channel within a
    particular band.
  + Add support for configuring Wake-on-LAN capabilitites.
  + Allow overriding the MTU for team device.
  + Usual pile of bug fixes and robustness improvements.
- Rebase NetworkManager-geoclue-interaction.patch .
* Wed Aug 19 2015 dimstar@opensuse.org
- Toggle with_cacert_patch to 1: the patch has been rebased.
* Tue Aug 18 2015 bastianholst@gmx.de
- Change nfs dispatcher-script to be more reliable in mixed ip v4
  v6 environments.
* Thu Aug  6 2015 glin@suse.com
- Rebase nm-probe-radius-server-cert.patch for 1.0.4 (bsc#938198).
* Thu Aug  6 2015 dimstar@opensuse.org
- Add explicit pkgconfig(udev) BuildRequires: we need it to define
  %%{_udevdir}.
* Wed Jul 15 2015 dimstar@opensuse.org
- Update to version 1.0.4:
  + The MTU setting from an IPv6 neighbor discovery Router
    Advertisements is now ignored if applying it would result in
    invalid configuration.
  + Some configuration options can now be changed without
    restarting the daemon. Notably, this applies to 'dns',
    'connectivity' and 'ignore-carrier' settings.
  + The connection activation was made more robust. If an active
    connection is reactivated, the device it's active on takes
    precedence. If an attempt is made to activate a connection on a
    different device than it is active on, the activation proceeds
    removing the connection from the active device.
  + The device specifiers in configuration files now support
    negation via 'except:' match.
  + Devices that only have IPv6 link-local address are no longer
    assumed to be connected.
  + nmcli now provides hints and tab-completion for enumeration
    properties.
  + If the IPv6 interface tokens are set they are honored when
    creating an interface identifier for IPv6 addressing.
  + NetworkManager now maintains correct routing configuration when
    multiple interfaces are connected to the same network.
  + The management of devices can now be controlled with udev
    rules. The veth devices as well as the virtual Ethernet devices
    of various virtualization tools (VMWare, VirtualBox, Parallels
    Workstation) are now ignored by default.
  + The IPv6 privacy extensions are now enabled by default and
    handling of the ip6-privacy sysctl has been improved.
  + Activating a Bond, Bridge or Team device can now optionally
    activate the slave connections as well. The behavior is
    controlled with 'connection.autoconnect-slaves' property.
  + The platform support code has been refactored, resulting in
    better scalability in large configurations.
  + Changes to network interfaces configuration done outside
    NetworkManager are now picked up and exposed to the user via
    NetworkManager API and tools.
  + A connection can now optionally leave externally configured
    default route in place instead of overriding it. The behavior
    is controlled with 'ipv4.never-default' and
    'ipv6.never-default' properties.
  + Multiple crasher and memory leak bugs in the daemon were fixed.
  + Multiple bugs that could cause the client tools to hang or
    crash were fixed.
  + nmcli allows multiple devices for 'nmcli device
    disconnect/delete'.
  + Firewall zone is added to firewalld for device-based VPN
    connections too.
- Toggle with_cacert_patch to 0: the Radius CA patch neeeds to be
  reworked. Wrap applying the patch into a with_cacert_patch
  condition, to make enabling/disabling a one-stop change.
* Wed May  6 2015 dimstar@opensuse.org
- Update to version 1.0.2:
  + Wi-Fi devices now indicate support for 2GHz and 5GHz
    frequencies.
  + "nmcli device" output now indicates physical port ID
  + New config items added to the 'ifcfg-rh' plugin:
  - IPV4_ROUTE_METRIC and IPV6_ROUTE_METRIC.
  - DEVTIMEOUT.
  - IPADDR and PREFIX are now supported for specifying address
    ranges of shared IPv4 connections.
  + Dispatcher scripts now get a CONNECTION_FILENAME variable with
    the path to the configuration file for the connection.
  + An example dispatcher script that is able to apply complex
    routing rules (such as setting up policy-based routing) for
    'ifcfg-rh' connections was added to examples/dispatcher/.
  + 'mode' key of Bond device options property now accepts numeric
    values.
  + Connection attempts for devices without carrier on startup now
    wait for carrier to appear within a short timeout instead of
    failing immediately. This makes system startup more robust.
  + Bridge connectivity is now properly restored on resume from
    suspend.
  + The D-Bus name is acquired earlier during the daemon startup.
    This makes it possible for the systemd service manager to
    optimize the service startup so that services that require
    networking are activated sooner contributing to faster system
    start up time.
  + A lot of memory leak problems were fixed, resulting in reduced
    memory usage. Many of them were discovered as a result of
    improvements in use of Valgrind in the testing infrastructure.
  + Management of 'teamd' daemon instances for Team devices is now
    more robust.
  + The 'dnsmasq' daemon respawns when it terminates and it is
    configured for management of DNS resolver configuration.
  + Hostnames that are not fully qualified are no longer sent to a
    DHCPv6 server for a dynamic DNS update.
  + Connection UUIDs are now checked for uniqueness when connection
    configurations are read.
  + Receipt of a NDP Router Advertisement can no longer lower the
    IPv6 hop limit (CVE-2015-2924).
  + Many other bugs were fixed.
  + Updated translations.
* Thu Mar 12 2015 dimstar@opensuse.org
- Add NetworkManager(cacert-patch) provides: to be toggled to 0
  whenever we disable nm-probe-radius-server-cert.patch. Other
  packages that consume the ABI introduced by this patch can
  specify this as a requirement.
* Tue Mar  3 2015 glin@suse.com
- Reabse nm-probe-radius-server-cert.patch
* Thu Feb 12 2015 dimstar@opensuse.org
- Add rp-pppoe BuildRequires, so configure can autodetect the path
  to the pppoe binary.
- Recommend rp-pppoe: the program is needed for NetworkManager to
  be able to initiate PPPoE connections (commonly used by ADSL
  providers). It is not strictly required to operate NM in most
  setups, thus only recommended (boo#903553).
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 1.0:
  + A new 'libnm' GObject-based client library to replace
    libnm-util/libnm-glib:
  - IP address, IP route, hardware address, and other properties
    are now represented as strings.
  - Based on GIO's GDBus bindings instead of dbus-glib.
  - Uses modern GObject APIs including GAsyncResult and GVariant.
  - See https://wiki.gnome.org/Projects/NetworkManager/libnm.
  + Devices and VPN connections now have individual default routes.
    Priorities are handled through configurable route metrics.
  + nmcli now supports password requests and PolicyKit
    authorizations.
  + A faster, lighter-weight (though less capable) internal DHCP
    client has been added and may be selected with the
    "dhcp=internal" option. It supports fewer DHCP options and
    does not yet support DHCPv6.
  + A new 'configure-and-quit=yes' option has been added for
    environments with less dynamic network configuration.
  + When running on 3.17 and later kernels, NetworkManager handles
    IPv6LL address assignment to ensure that IPv6 connectivity is
    not enabled until intentionally configured by the user.
  + NetworkManager no longer causes the nl80211 kernel module to be
    loaded on systems with no Wi-Fi devices.
  + Bluetooth DUN support now works with Bluez 5.x.
  + VPN connections can now persist across link changes and
    suspend/resume if their VPN plugin supports this feature.
  + A new 'ibft' settings plugin has been added to support
    firmware-based iBFT/iSCSI configurations. This functionality
    has been moved to 'ibft' from the 'ifcfg-rh' plugin.
  + IPv6 router advertisement MTUs are now respected.
  + NetworkManager no longer requires polkit libraries at runtime
    when Polkit support is enabled, and Polkit can be disabled at
    build time too.
  + Automatically created connections are now deleted when their
    device goes away.
  + 'nmcli dev connect' now attemts to create a connection if none
    exists.
  + Manually configured static IPv6 configuration is kept even if
    SLAAC fails.
  + Manpages for the 'keyfile' and 'ifcfg-rh' plugins now describe
    their configuration syntax and available options.
  + WWAN connections now support IPv6 if the modem and provider
    support IPv6.
  + Software devices (bridge, bond, team, etc) can now be deleted
    from the D-Bus API or with nmcli.
  + The manpages, documentation, and API annotations have received
    many cleanups.
  + Externally created virtual interfaces are no longer managed by
    NetworkManager until they are set "up" or activated via nmcli.
- Disable nm-probe-radius-server-cert.patch for now: needs rebase.
- Drop 0001-core-don-t-auto-launch-logind-bgo-741572.patch and
  NetworkManager-dhcpv6.patch: fixed upstream.
- Split out new subpackage typelib-1_0-NM-1_0 and libnm0.
- Require typelib-1_0-NM-1_0 and libnm0 by the -devel package.
- Add pkgconfig(bluez) BuildRequires.
- Replace pkgconfig(libsystemd-login) BuildRequires with
  pkgconfig(libsystemd) and pkgconfig(polkit-gobject-1) with
  pkgconfig(polkit-agent-1), following upstream.
* Sun Jan 25 2015 badshah400@gmail.com
- Update to version 0.9.10.1:
  + Kernel 'cache' routes (such as those added by IPv6 operations)
    are ignored, preventing unwanted CPU usage.
  + Vala bindings for libnm-glib async methods have been added.
  + Some interactions with external OpenVPN daemon default routes
    have been fixed.
  + Fixed usage of libnm-glib connectivity checking from
    garbage-collected languages.
  + An unusual delay acquiring a DHCP lease with dhcpcd has been
    fixed.
  + A libnm-glib crash has been fixed when multiple NMClients are
    created.
  + A failure to pass certificate blobs to wpa_supplicant has been
    fixed.
  + A failure to send the inner private key password to
    wpa_supplicant has been fixed.
  + nmcli now returns earlier when activating master interfaces.
  + nmtui password fields now correctly display the password.
  + The IPv6 hop limit is no longer mistakenly set to 0 in some
    cases.
  + Some DHCPv6 failures are no longer fatal.
  + Handling of DHCP 'nak' and 'expire' states has been fixed in
    some cases.
  + WiFi band locking has been fixed.
  + Support for Bluetooth DUN with Bluez5 has returned.
  + Non-local users can now control networking after
    authenticating with PolicyKit.
  + Externally added routes no longer have their metrics
    overwritten.
  + Some child interfaces (eg VPN or WWAN) are no longer
    deconfigured when recognized.
  + Support for the PrimaryConnection D-Bus property has been
    backported.
  + IPv6 RDNSS/DNSSL forced expiration is now handled properly.
  + An invalid route to the DHCP server is no longer added in some
    configurations.
  + A crash when external master/slave changes were made has been
    fixed.
  + Various nmtui bugs for slaves, WiFi, and IP address buttons
    have been fixed.
  + DHCP no longer fails due to SIGPIPE when the systemd journal
    is restarted.
  + Unmanaged slaves are now updated correctly when they
    disappear.
  + Cooperation with external team interfaces has been fixed.
  + Bridge STP property ranges are now properly checked.
  + Manager state is now properly updated on resume.
  + Slave interfaces are no longer released on exit.
  + Static IPv6 configuration is now added before SLAAC is
    started.
  + Allow shared connections to be started without a carrier.
  + A crash when disconnecting older Nokia phones has been fixed.
- Drop patches incorporated upstream:
  + 0001-core-don-t-auto-launch-logind-bgo-741572.patch.
  + NetworkManager-dhcpv6.patch.
* Thu Jan  8 2015 sfalken@opensuse.org
- Add NetworkManager-dhcpv6.patch: dhcp: let dhclient handle
  requesting the 'server-id' option (boo#912315).
* Thu Dec 18 2014 arvidjaar@gmail.com
- Add 0001-core-don-t-auto-launch-logind-bgo-741572.patch: do not
  trigger logind start on system startup to avoid deadlock
  (boo#905639).
* Tue Oct 28 2014 dimstar@opensuse.org
- Handle NetworkManager-dispatcher.service using the systemd
  macros.
- Enable NetworkManager-dispatcher.service in %%post: as this is a
  dbus service, the 'systemd unit' must be enabled in order to be
  fired up.
* Fri Sep 19 2014 fcrozat@suse.com
- modified patches:
  * systemd-network-config.patch: NM-wait-online should block only
    network-online.target, not network.target (bnc#889175).
* Thu Sep 18 2014 fcrozat@suse.com
- modified patches:
  * systemd-network-config.patch : ensure
    NetworkManager-wait-online.service is enabled when
    NetworkManager.service is (bnc#889175).
* Mon Aug 25 2014 fcrozat@suse.com
- Add
  nm-core-fix-crash-during-Wi-Fi-rescan-by-emitting-NM_DE.patch:
  fix regression in 0.9.8.10 causing crash in Wifi rescan.
* Tue Jul 22 2014 dimstar@opensuse.org
- Change ppp requires to %%requires_eq ppp: the plugin is installed
  in a versioned directory, and as such we do require the exact
  version of ppp (bnc#888442).
* Tue Jul 15 2014 glin@suse.com
- Rebase nm-probe-radius-server-cert.patch.
- Drop nm-remove-AP-always-on-device-disconnect.diff: No longer
  needed.
* Wed Jul  9 2014 dimstar@opensuse.org
- Update to version 0.9.10.0:
  + Added a new curses-based client called "nmtui" for easier
    console operation.
  + Added interactive connection editing and creation mode to nmcli
    with detailed help and tab completion support.
  + nmcli bash completion has been greatly improved.
  + Added support for Data Center Bridging (DCB) and FibreChannel
    over Ethernet (FCoE).
  + IPv6 autoconfiguration is now done in userspace with libndp
    instead of the kernel.
  + The D-Bus daemon is no longer required for root-only operation.
  + WiFi, ADSL, WWAN, and Bluetooth are now optional plugins,
    reducing install size.
  + Added support for Infiniband Partitions.
  + Network connection files are no longer watched by default, use
    "nmcli con reload" to notice changes made externally or set
    "monitor-connection-files=true" in NetworkManager.conf's
    [main] section.
  + Connections can now be locked to interface names in addition to
    hardware/MAC addresses.
  + A new "ignore-carrier" configuration option is available to
    ignore the carrier on selected interfaces.
  + A new "dns=none" option has been added to suppress changes to
    /etc/resolv.conf.
  + Changes made to IP addresses, IP routes, and master/slave
    relationships from external tools are now recognized and
    reflected in the D-Bus API.
  + Assuming the existing configuration of interfaces without
    changing that configuration is now more reliable.
  + The 'root' user is no longer subject to PolicyKit access
    controls and usage of D-Bus "at_console" permissions has been
    removed.
  + Configuration file snippets can be dropped in
    /etc/NetworkManager/conf.d to change smaller sets of
    configuration options.
  + Added IP-level support for more software/virtual interfaces
    types including GRE, macvlan, macvtap, tun, tap, veth, and
    vxlan interfaces.
  + All network interfaces known to the kernel are now exposed
    through the D-Bus interface.
  + Improved support for routing-only VPNs like
    openswan/libreswan/strongswan.
  + Added support for "temporary" connections which are not saved
    to disk until requested.
  + Added WWAN autoconnect support and fixed issues with airplane
    mode handling.
  + NetworkManager-wait-online systemd service behavior is more
    reliable.
  + The dispatcher timeout has increased to 10 minutes, and new
    "pre-up" and "pre-down" events have been added which block
    activation until complete.
  + NetworkManager no longer prevents Wake-on-LAN functionality
    from working.
  + PPPoE now requires userland "rp-pppoe" to work around kernel
    bugs with that prevent detecting server-side termination of the
    PPP link.
  + An ARP announcement is now sent after IPv4 addresses are
    configured.
  + Added a DNS plugin for dnssec-trigger for better DNSSEC
    operation.
  + More properties are now exposed via the D-Bus properties
    interface in addition to getter/setter functions.
  + Added support for custom IP address ranges for Shared
    connections.
  + Fatal connection failures now block automatic reconnection more
    reliably.
  + VPN connection IP details are now available via the D-Bus
    interface.
  + VPN plugins can now request additional/new secrets from the
    user during the connection process.
  + 'veth' interfaces are now unmanaged by default to cooperate
    better with external tools.
- Add pkgconfig(libndp) BuildRequires: new dependency.
- Disable nm-probe-radius-server-cert.patch,
  nm-don-t-consider-not-needed-secrets-for-has_system_secr.diff and
  nm-treat-not-saved-secrets-just-like-agent-owned-when-cl.diff:
  closer investigation is needed if the upstream changes caught all
  the cases we tried to address with these hack patches.
- Rebase NetworkManager-geoclue-interaction.patch.
- Pass --with-nmtui to configure to ensure the text mode UI (tui)
  is being built.
- Add pkgconfig(libnewt) BuildRequires: dependency for the tui.
* Fri Apr 25 2014 dimstar@opensuse.org
- Update to version 0.9.8.10:
  + Fixed a bug that allowed a user to disconnect a connection that
    they didn't have permissions on.
* Fri Apr  4 2014 dimstar@opensuse.org
- Update to version 0.9.8.9:
  + Fixed two problems that could result in gnome-shell showing
    incorrect icons. In particular, fixed the problem where the
    network icon would disappear when certain VPNs were activated.
  + Dispatcher scripts now receive correct IPv6 addresses, and also
    correct DHCP information on lease-change events.
  + NetworkManager no longer tries to start ModemManager itself on
    systemd-using systems.
  + Activating a second ethernet connection while another is
    already active will now not move the default route.
  + Fixed some edge cases where one user could deactivate a
    connection owned by another.
  + Fix handling of dhcp-send-hostname property with ifcfg-rh.
  + DHCP now works even if you have a global dhclient.conf that
    specifies a (non-NetworkManager) script to run.
  + The dhcpcd backend now requests that dhcpcd only do DHCPv4,
    fixing some WWAN devices that don't react well to seeing IPv6
    packets.
  + Fixed the default value of bridge priority.
  + The D-Bus policy file has been updated to include the
    NetworkManager-iodine VPN plugin.
  + It is possible to specify the path to dnsmasq at build time.
  + Removed a GLib 2.32 dependency that accidentally snuck into
    0.9.8.8.
  + Fixed a bunch of memory leaks.
  + Fixed a bunch of miscellaneous crashes.
  + Removed some less-useful bits of logging output.
- Rebase NetworkManager-geoclue-interaction.patch.
* Mon Mar 24 2014 dimstar@opensuse.org
- Fix files list: do not expect pppd plugin version 2.4.5 in the
  directory name.
* Mon Feb 24 2014 dimstar@opensuse.org
- Add NetworkManager-geoclue-interaction.patch: allow the user
  "srvGeoClue" (as used by the geoclue2 service) to query
  NetworkManager,
* Fri Oct 11 2013 dimstar@opensuse.org
- Update to version 0.9.8.8 (bnc#845542):
  + Fixes to the BlueZ code.
  + A few memory leak fixes.
  + Minor docs fixes.
* Thu Oct 10 2013 rmilasan@suse.com
- Switch to systemd check for the nfs script if enabled or not.
  Also do not exit with error code if nfs script is not enabled.
* Tue Oct  1 2013 glin@suse.com
- Update nm-probe-radius-server-cert.patch to probe the server with
  the user credential (bnc#817585)
* Mon Sep 30 2013 dimstar@opensuse.org
- Update to version 0.9.8.6:
  + Now supports BlueZ 5. If you are still using BlueZ 4, configure
    with --enable-bluez4 to disable BlueZ 5 support and enable
    BlueZ 4 support.
* Fri Sep 13 2013 crrodriguez@opensuse.org
- Pass nmrundir="/run/%%{name}" to make and makeinstall:
  + Use /run/NetworkManager instead of /var/run/NetworkManager as
    runtime directory.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.9.8.4:
  + Removed some spurious warnings.
  + Root clients running outside a login session now have the right
    permissions.
  + WiFi AP mode and EAP-FAST support are now detected correctly.
  + Bonding config removes inappropriate options when switching
    modes.
  + Fix reading of bond connections with keyfile plugin.
  + Fix hang when dbus-daemon restarts.
  + Fix crash when VPN disconnection fails.
  + The dispatcher now exposes IPv6 VPN info, and IPv4/IPv6 DNS
    search domains.
  + Build fix to support dhcpcd 6.x.
  + Fix crash on startup when no dhcp client is available.
  + Fix device descriptions when using the latest udev.
  + Fix some possible obscure problems at startup.
  + Always clear the default route correctly when disconnecting
    mobile broadband.
  + Keyfile plugin now ignores more emacs temporary files.
  + When using dnsmasq, pass all nameservers to it, not just the
    first.
  + Kill dhclient if nm-dhcp-client-action encounters a fatal
    error.
  + Fix dispatcher systemd unit install.
  + Make ifcfg-rh VLAN parsing match initscripts better.
  + Change threshold for WiFi background scanning under WPA
    Enterprise.
  + Fix crash when deleting a currently-active connection.
  + Fix ifcfg-rh's handling of IPV6_DEFAULTGW.
  + Fix manager State transitions when connectivity checking is
    enabled.
  + Add Connectivity property to distinguish portals from "limited
    connectivity".
  + Add PrimaryConnection and ActivatingConnection properties to
    simplify UI code.
  + Old connection files containing UUIDs without hyphens work
    again.
- Rebase systemd-network-config.patch.
* Mon Jul  1 2013 coolo@suse.com
- avoid suse-release, it moves NM behind java in bootstrap and
  all features that configure.ac enabled for suse-release are
  enabled with --with anyway
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Memory leak fixes.
  + Ensure the ifcfg-rh plugin saves the bridging STP setting
    correctly.
  + Also request static routes from DHCP servers.
  + Fix crash when dbus-daemon restarts.
  + Look harder for the machine ID and don't crash if we don't have
    one.
  + Copy DHCP leasefiles from the previous location if necessary.
  + Wait up to 120 seconds for modems to connect.
  + Don't crash for PPPoE connections with no wired setting.
  + Fix AvailableConnections for some WiFi connections.
  + Ensure new available connections generate the PropertiesChanged
    signal.
  + Ensure the keyfile plugin reads all-default VLAN connections
    correctly.
  + Suppress the kernel's automatic creation of bond0.
  + Make the SecretAgent API introspectable for bindings.
  + Ensure ActiveConnections get torn down when device is
    unavailable.
  + Ensure ifupdown plugin rechecks unmanaged devices on interface
    changes.
  + Don't prematurely think IPv6 has succeeded due to left-over
    addresses.
  + Fix various systemd issues and add service file for the
    dispatcher.
  + Updates for new ModemManager API changes.
  + Fix crash on Wi-Fi when IP configuration times out.
- Rebase systemd-network-config.patch.
* Fri May 10 2013 wstephenson@suse.com
- Readd nm-probe-radius-server-cert.patch, as it is not yet merged
  upstream (bnc#574266, bnc#771185).
* Tue Apr 30 2013 jslaby@suse.com
- Add sysconfig and suse-release BuildRequires to properly
  configure for suse (bnc#817592).
- Add --with-netconfig=yes to configure call.
- Add additional test in build section to ensure netconfig is
  detected. This is needed as specifying --with-netconfig=yes does
  not fail configure if not found.
* Tue Apr 23 2013 dimstar@opensuse.org
- Pass --with-modem-manager-1 to configure: we already have a new
  enough ModemManager to make use of this.
- Add pkgconfig(mm-gib) BuildRequires: needed for above switch to
  take effect.
* Thu Mar 14 2013 sbrabec@suse.cz
- Re-enabled translation-update-upstream.
* Thu Mar  7 2013 sbrabec@suse.cz
- Recommend avahi-autoipd used for IPv4LL support.
* Sun Feb 24 2013 zaitor@opensuse.org
- Update to version 0.9.8.0:
  + Fix issue with duplicate ActiveConnection objects if a
    connection was reactivated on a device.
  + Fix race when looking up hostname and concurrently updating
    DNS.
  + Always load the 'keyfile' settings plugin, even if no plugins
    are specified.
  + Add a new WiFi device ADHOC capability; not all devices/drivers
    support IBSS mode.
  + Fix an issue with quick wpa_supplicant restarts not being
    noticed.
  + Expose the AvailableConnections property through libnm-glib.
  + Fix usage of libnm-glib's NMRemoteConnection from GObject
    introspection.
* Sat Feb 23 2013 dimstar@opensuse.org
- Update to version 0.9.7.997:
  + libnl 3.2.7 or later is required.
  + The internal crashdump handling has been removed.
  + A DHCPv6 DUID is now generated from /etc/machine-id and sent to
    the DHCPv6 server, if not overridden by an
    administrator-defined DUID.
  + Bond interfaces now wait for a ready slave before starting
    automatic IP configuration.
  + The kernel WiFi rfkill state is now synced to the
    user-requested WirelessEnabled state at startup.
* Fri Feb 22 2013 dimstar@opensuse.org
- Update to version 0.9.7.995:
  + New AvailableConnections property for Device objects.
  + Better handling of various rfkill/Airplane Mode switches
  + Fixed handling of DNS servers for some mobile broadband devices
  + Don't duplicate various IPv6 routes added by the kernel
  + Ensure buggy ethernet driver carrier indications are handled
    correctly
  + Fix crash in dnsmasq plugin when no nameservers were presen
  + Add support for 4G LTE network modes
  + Fix signal handling when daemonizing at startup
  + Don't autoconnect to WiFi networks that have never successfully
    connected
  + Only request new WiFi secrets during the initial association or
    when the secrets are known to be wrong, not every time the
    connection randomly fails
  + Add capability to autoconnect VPN connections when a parent
    connection succeeds
  + Add configure-time option for "permissive" system connection
    editing policy
  + Various libnm-glib fixes for asynchronous usage
  + Fix gateway handling when given with secondary IP addresses
  + Optionally listen to systemd for suspend/resume events instead
    of UPower
  + Fix 'seen-bssids' property when retrieving WiFi connections via
    D-Bus
  + Add support for AP-mode WiFi hotspots (instead of just Ad-Hoc)
  + Add a "slaves" property to Bond devices
  + Add support for ModemManager 0.7/0.8
  + Allow more human-readable formatting of IP address in keyfile
    connections
  + Drop support for dhclient v3
  + Add support for DHCPv6 server-side Dynamic DNS
  + Add support for bridge master devices and bridge ports
  + Fix canceling secrets requests in GUI agents
  + Always enable Proactive Key Caching (PKC, also called OKC) for
    WPA Enterprise WiFi configurations
- Replace --with-distro=suse configure parameter with
  - -enable-ifcfg-suse, following upstreams changes, which allow for
  granular configuration.
- Drop NetworkManager-systemd-suspend.patch and
  NetworkManager-upower-out.patch: fixed upstream.
- Rebase systemd-network-config.patch.
* Thu Feb 21 2013 mt@suse.com
- Added migration hook enabling NetworkManager.service on update
  from openSUSE < 12.3 and NETWORKMANAGER=yes setting (bnc#803058).
* Mon Jan 14 2013 mt@suse.com
- Install network.service alias, that points to the enabled service
  and obsoletes the use of NETWORKMANAGER=yes/no sysconfig variable
  in /etc/sysconfig/network/config (bnc#764055,bnc#764336,bnc#798348).
- Requires sysconfig-0.80.0
* Thu Dec  6 2012 fcrozat@suse.com
- Update systemd-network-config.patch: ensure
  NetworkManager.service is Before network.target (bnc#789421).
* Tue Nov 27 2012 dimstar@opensuse.org
- Move the udev files to the right location:
  + Define _udevdir based on the udevdir variable of udev.pc.
  + Pass --with-udev-dir=%%{_udevdir} to configure.
  + Use %%{_udevdir} in the files section as appropriate.
* Thu Nov  8 2012 dimstar@opensuse.org
- Switch on systemd support: change with_systemd defines to 1.
* Tue Nov  6 2012 dimstar@opensuse.org
- Add NetworkManager-systemd-suspend.patch and
  NetworkManager-upower-out.patch: Listen to systemd for
  suspend/resume when built with systemd support. The upower
  signals will never be emitted.
- When building with systemd support, add gnome-common
  BuildRequires and call to gnome-autogen.sh, as above patches
  touch the build system.
* Sat Oct 27 2012 dimstar@opensuse.org
- Update to version 0.9.6.4:
  + Add libnm-glib API to get bond interface slaves.
  + Fix detection of some ACPI-based laptop airplane-mode/rfkill
    switches.
  + Fix a crash when a VLAN interface is removed.
  + Fix a regression setting the Device 'driver' and 'firmware'
    properties.
  + Fix a stale-properties issue with libnm-glib when device state
    changes.
  + Ignore cached/cloned route notifications from the kernel.
  + Work around buggy kernel driver carrier notifications.
  + Fix a crash with dnsmasq local caching nameserver functionality
    when no nameservers are present.
  + Add "Speedport W 501V" to list of manufacturer default SSIDs.
  + Various documentation fixes.
  + Fix routing setup if gateway is not given with the first IP
    address.
  + Enhance nmcli for additional VLAN and bonding functionality.
  + Fix possible crash when removing OLPC Mesh devices.
* Wed Sep 26 2012 glin@suse.com
- Disable nm-remove-AP-always-on-device-disconnect.diff: the AP
  might be removed from the list forever due to the AP list update
  method change since 0.9.4.0 (bnc#768564)
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.9.6.0:
  + Allow customized dnsmasq local caching nameserver config via
    /etc/NetworkManager/dnsmasq.d/
  + Fixes for VLAN and bonding when libnl2 or earlier are used
  + D-Bus API, libnm-glib, libnm-util, and GObject Introspection
    documentation updates.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.9.5.96:
  + Fix various crashes and issues in the ifcfg-rh system settings
    plugin
  + Fix race with multiple interfaces running DHCP at the same time
  + Add Linux From Scratch (LFS) support.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.9.5.95:
  + Many libnm-glib fixes, including crashes when NetworkManager
    restarts
  + Enhanced IPv6 stability and compatibility.
  + Fix regression in carrier handling for devices that don't
    support carrier detect.
  + Add ability to connect to new WiFi networks from nmcli.
  + Add native support for ADSL modems using PPPoE or PPPoATM.
  + Reduce number of changes made to DNS information during
    connection setup.
  + Add support for IPv6-enabled VPN connections.
  + Add device driver version, firmware version, and autoconnect
    properties to D-Bus API.
  + Add on-demand WiFi scan support.
  + Fix IPv6 default gateway handling for DHCPv6.
  + Add Vala language bindings.
- Drop patches that were merged upstream:
  + nm-ensure-bindings-created-NMClient-object-work.patch
  + nm-gerror-must-be-null.patch
  + nm-ppp-build-error.patch
  + nm-ensure_inited-fixing.patch
  + nm-null-out-on-dispose.patch
  + nm-probe-radius-server-cert.patch
  + nm-wireless-strength.patch
- Add vala BuildRequires: needed to build the new vala bindings.
* Mon Aug 20 2012 binli@opensuse.org
- Add nm-wireless-strength.patch, fix wireless status for ipw2200.
  (bnc#755541, bgo#675017).
* Fri Aug 17 2012 fcrozat@suse.com
- Remove dbus system-service for NetworkManager, to prevent
  warnings about it not being running (bnc#738596)
* Wed Jul 18 2012 glin@suse.com
- Add nm-probe-radius-server-cert.patch to probe the certificate
  of the RADIUS server (bnc#574266, bnc#771185)
- Add nm-null-out-on-dispose.patch to fix crash in gnome-shell or
  any other program using libnm-glib (bgo#674473)
* Thu Jun  7 2012 badshah400@gmail.com
- Add nm-ensure-bindings-created-NMClient-object-work.patch to fix
  "nmcli con" not working (bgo#672812, bnc#766045).
* Sat Jun  2 2012 binli@opensuse.org
- Add nm-ppp-build-error.patch, don't use struct ifpppstatsreq
  that was removed from linux/ip_ppp.h in recent kernels.
* Tue May 29 2012 binli@opensuse.org
- Add nm-ensure_inited-fixing.patch, ensure initialization
  in get_property() calls.(bnc#764290).
* Tue Apr 17 2012 jeffm@suse.com
- Add nm-gerror-must-be-null.patch: GError * must be initialized to
  NULL (bnc#757656).
* Sat Mar 24 2012 vuntz@opensuse.org
- Update to version 0.9.4.0:
  + Removed support for WiFi Ad-Hoc WPA connections due to kernel
    bugs
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 0.9.3.997:
  + A bug causing IPv6 address assignment to fail on newer kernels
    with libnl3 has been fixed
  + Fix a bug in the ifcfg-rh plugin with backticks in WPA
    passphrases
  + Ensure connections that cannot be stored are ignored by the
    ifnet plugin
  + Enable out-of-the-box IPv6 connectivity by allowing IPv4 to
    fail if IPv6 succeeds
  + Allow proxying of DNSSEC data when using the dnsmasq local
    caching nameserver plugin
  + Add support for multiple domain names sent from VPN plugins
* Tue Mar 13 2012 vuntz@opensuse.org
- Add NetworkManager Supplements to
  NetworkManager-device-plugin-wimax so that it gets automatically
  installed by default.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 0.9.3.995:
  + Linux Wireless Extensions (WEXT) support can be disabled at
    configure time with --with-wext=no
  + IPv6 Privacy Extensions are now enabled by default for new
    connections
  + Support for checking Internet connectivity has been added
  + The ifnet system config plugin rewrites config files less often
- Add pkgconfig(libsoup-2.4) BuildRequires and pass
  - -enable-concheck to configure to enable internet connectivity
  check.
* Wed Feb 29 2012 dimstar@opensuse.org
- Add with_wimax define, which prepares NM for wimax. If with_wimax
  is defined to 1:
  + Add pkgconfig(libiWmxSdk-0) BuildRequires
  + Change --disable-wimax to --enable-wimax in configure
  + Create NetworkManager-device-plugin-wimax subpackage
* Thu Feb 23 2012 vuntz@opensuse.org
- Get ready for full-switch to systemd:
  + Add a with_systemd macro, currently set to 0 as the systemd
    support implies no support for ConsoleKit, which we want to
    keep until sysvinit is not supported anymore.
  + Add pkgconfig(libsystemd-login) BuildRequires and pass
  - -with-session-tracking=systemd to configure if we build
    systemd support.
- Move to libnl3:
  + Remove pkgconfig(libnl-1) BuildRequires.
  + Add pkgconfig() BuildRequires: libnl-3.0, libnl-genl-3.0,
    libnl-route-3.0.
- Remove libiw-devel BuildRequires: it's not needed anymore.
- Stop changing libexecdir to %%{_prefix}/lib/NetworkManager: there
  is no need for this.
* Sat Feb 18 2012 dimstar@opensuse.org
- Update to version 0.9.3.990:
  + Better handling of WiFi devices via nl80211 when available
    (instead of WEXT)
  + IP configuration is now non-blocking; waiting for IPv6 RA no
    longer blocks the device from activating if IPv4 is ready and
    vice versa
  + Addded support for firewall "zones" via FirewallD
  + Added basic support for bonded interfaces
  + WiFi connections are no longer locked to a specific MAC address
    if they are "locally administered" addresses (ie, 02:::::)
  + New state change reasons have been added for mobile broadband
    PIN errors
  + Agent-owned secrets are now sent to agents for newly created
    connections
  + Support for non-UTF8-encoded 802.1x passwords has been added
  + libnm-glib now fetches some properties more aggressively (like
    active connections, access points, etc)
  + Added basic support for IP-over-Infiniband interfaces
  + Added support for device plugins and converted WiMAX support to
    a plugin for easier packaging and simpler dependencies
  + Added support for VLAN interfaces
  + Added support for 802.1x EAP-FAST authentication
  + Added non-blocking mode and API to libnm-glib
- Rebased systemd-network-config.patch.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib files into their own subpackages:
  typelib-1_0-NetworkManager-1_0 and typelib-1_0-NMClient-1_0.
- Add typelib-1_0-NetworkManager-1_0 and typelib-1_0-NMClient-1_0
  Requires to devel subpackage.
* Wed Dec  7 2011 fcrozat@suse.com
- Update systemd-network-config.patch to handle NM_TIMEOUT value 0
  as no timeout (bnc#730628).
* Tue Nov 15 2011 dimstar@opensuse.org
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.9.2.0:
  + Fixes for building with recent GLib versions.
  + Don't update routing and DNS until a device is managed.
  + Fix bug causing IPv6 RA-provided routes to be ignored.
  + Fix possible wrong handling of 'keyfile' connection
    certificates.
  + Correct Shared connection IP address range to be as documented.
* Mon Oct 31 2011 dimstar@opensuse.org
- Update to version 0.9.1.95:
  + Fix a crash when deleting default wired connections
  + Fix a security issue in the ifcfg-rh plugin with newlines in
    file names
  + Fix the "SpecificObject" property for active VPN connection
    objects
  + Improve handling of rfkill on some platforms
  + Spaces no longer used in ifcfg config file names
  + IPv6 RAs are now accepted when forwarding is configured
  + dnsmasq local caching nameserver plugin cache size bumped to
    400 entries (from 150)
  + Fix handling of SSIDs in the keyfile plugin
  + Fix some GObject Introspection annotations in libnm-glib and
    libnm-util
  + Fix setting hostnames from DHCP
- Drop nm-udev-rfkill-handling.patch: fixed upstream.
* Fri Oct 14 2011 lnussel@suse.de
- avoid annoying polkit popups when connecting to 802.11x networks
  that are supposed to ask for passwords (bnc#713639)
- also avoid asking for a password (and thereore polkit auth) when
  an AP goes of range.
* Mon Oct  3 2011 glin@suse.com
- Add nm-udev-rfkill-handling.patch to improve the rfkill handling
  (bnc#709733,bgo#655773)
* Tue Sep 27 2011 fcrozat@suse.com
- Update systemd-network-config.patch to correctly handle /usr over
  NFS.
- Use latest systemd rpm macros.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 0.9.1.90:
  + Support for libnl2 and libnl3 and various leak fixes
  + Various small bug fixes in the ifnet config plugin
  + Ensure IPv6 link-local DNS servers work correctly in the
    dnsmasq DNS plugin
  + Add ability for nmcli to delete connections
  + Fix setup of connection sharing with newer iptables versions
  + Ensure WiMAX activation emits correct signals (fixes initial
    signal strength)
  + Fix an issue with duplicated keyfile connections
  + Ensure the 'novj' options is passed through to pppd
  + Store timestamps for VPN connections too
- Remove explicit Requires for libnl: this is a library, so the
  right Requires will be automatically be added.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Implement baselibs for package
* Fri Sep  9 2011 fcrozat@suse.com
- Update systemd-network-config.patch to enable
  NetworkManager-wait-online.service too (and read timeout value
  from /etc/sysconfig/network/config).
* Tue Sep  6 2011 vuntz@opensuse.org
- Apply shared library packaging policy (bnc#689039):
  + Create libnm-util2, libnm-glib4, libnm-glib-vpn1 subpackages.
  + Add Provides/Obsoletes for NetworkManager-glib to libnm-glib4.
  + Changes NetworkManager-glib Requires in devel subpackage to
    libnm-util2, libnm-glib4 and libnm-glib-vpn1 Requires.
  + Remove NetworkManager-glib Requires from main subpackage: there
    is no reason to have an explicit Requires for the libraries.
- Merge doc subpackage in devel subpackage, with appropriate
  Provides/Obsoletes.
- Rename nm-system-settings.conf source to NetworkManager.conf, to
  follow the new non-deprecated scheme for configuration. Note that
  this uses the same format, so there's nothing to adapt. If users
  have an old modified version of nm-system-settings.conf, then it
  will still be used. Fix bnc#689042.
- Mark %%{_sysconfdir}/NetworkManager/NetworkManager.conf with
  %%config(noreplace).
* Tue Aug 30 2011 fcrozat@suse.com
- Add empty systemd macro to fix build on 11.4
- Update systemd-network-config.patch to disable dbus activation
  for NetworkManager, it was causing KDE timeout when NM was not
  handling network (bnc#714962).
* Wed Aug 24 2011 dimstar@opensuse.org
- Update to version 0.9.0:
  + fdo#39463: Ensure NM can talk to newly installed VPN plugins
  + Don't autoconnect disabled modems.
  + Preserve agent secrets the right way.
  + Preserve agent secrets over Update operation.
  + Add libnl-3 API compatibility.
  + Add libnl-2 support with libnl-1 compatibility.
  + Fix DBus signal signatures in supplicant.
  + Handle a few more possible D-Bus activation errors.
  + Fix integer list SSID parsing.
  + bgo#652512: Fix crash for AddAndActivateConnection() D-Bus call
  + Add missing U2600 GSM band enumeration.
- Drop f15-branch.patch: No longer required.
* Wed Aug 24 2011 fcrozat@suse.com
- no longer package /var/run/NetworkManager, not used by NM
  anymore. Package /var/lib/NetworkManager instead.
- Add systemd-network-config.patch: follow network configuration to
  not start NM under systemd if it is disabled system-wide.
- enable systemd service for NetworkManager
* Thu Jun  9 2011 fcrozat@suse.com
- Update to version 0.8.9997:
  + Fix symbol exports in libnm-glib.
  + Fix some gobject introspection annotations.
  + WiMax fixes : do not attemp to connect when scanning.
  + Recognize PKCS#8 private keys and check passwords.
  + Allow _ as valid character for GSM APN.
  + Improve PolicyKit integration.
  + Fix up Ad-Hoc frequency when connecting.
  + Don't complay if ConsoleKit database isn't found at startup.
  + Improve openconnect migration.
  + Handle DHCP options perperty correctly.
  + Only send  hostname without domain as host-name option for
    DHCP.
  + Fix crash when SSID is missing
  + Make auto-activation retries really work.
  + Fix dispatcher handling of empty VPN interface.
- Update f15-branch.patch from the git branch.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 0.8.999:
  + IPv6 compliance and RDNSS lifetime fixes
  + systemd cooperation fixes
  + API fixes for clients creating wifi connections
  + API additions to make client code simpler
  + Startup efficiency fixes by not parsing the ConsoleKit database
    more than required
  + Fixes for IBM s390 CTC-type network devices
  + Fixes for WWAN enable/disable status
  + Fixes for ifcfg-rh configuration plugin handling of IP addresses
  + Support for Easytether Android handset tethering
  + Better handling of rfkill for WiFi and WiMAX interfaces
  + Addition of IPv6 support for dispatcher scripts
  + Fixed handling of DER-format certificates
- Update f15-branch.patch from the git branch.
* Mon May  2 2011 vuntz@opensuse.org
- Remove polkit-unauthorized-privilege filter from
  NetworkManager-rpmlintrc as polkit-default-privs got updated.
* Mon May  2 2011 vuntz@opensuse.org
- Update NetworkManager-rpmlintrc:
  + Remove filter for suse-dbus-unauthorized-service, this got
    fixed.
  + Update polkit-unauthorized-privilege to be more specific since
    only org.freedesktop.NetworkManager.settings.modify.hostname is
    missing now.
  + Mention bnc#680140, where we are tracking this.
* Thu Apr 21 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: dbus-1-devel, dbus-1-glib-devel, libgudev-1_0-devel,
    libnl-devel, libuuid-devel, mozilla-nss-devel, polkit-devel.
  + New ones: dbus-1, dbus-glib-1, glib-2.0, gudev-1.0, libnl-1,
    nss, polkit-gobject-1, uuid.
- Remove libgcrypt-devel BuildRequires: it's only needed if we
  don't use nss.
- Remove explicit Requires for various packages in devel subpackage
  as they should be brought with pkgconfig() magic: dbus-1,
  dbus-1-glib, dbus-1-devel, glib2-devel, dbus-1-glib-devel,
  libgcrypt-devel, libgpg-error-devel.
- Add fdupes BuildRequires to remove duplicate files in
  /usr/share/gtk-doc.
- Do not call /sbin/ldconfig in %%post/%%postun of main binary
  package as there is no library there.
- Stop manually building nm-online: it's already installed with the
  standard build.
- Drop NetworkManager-frontend.conf as this was for the
  NetworkManager 0.8 world. This is now integrated in
  /etc/dbus-1/system.d/NetworkManager.conf. Fix bnc#689043.
- Ship /etc/NetworkManager/VPN directory.
* Wed Apr  6 2011 fcrozat@novell.com
- Add back f15-branch.patch: all patches from Fedora15 branch,
  mostly for fixing compatibility issues.
* Tue Apr  5 2011 dimstar@opensuse.org
- Update to version 0.8.998 (0.9.0-rc1):
  + Fix memory leaks
  + libnm-glib: Fix crashes
  + Fix wired connection completion
  + Updated translations.
  + Bugs fixed: bgo#646300, bgo#646115, bgo#646335, bgo#646375,
    bgo#645927.
- Drop f15-branch.patch: merged.
- Remove autoreconf call: no more patches.
* Tue Mar 29 2011 fcrozat@novell.com
- Add f15-branch.patch: all patches from Fedora15 branch, mostly
  for fixing compatibility issues.
* Sun Mar 20 2011 dimstar@opensuse.org
- Update to version 0.8.997 (0.9 beta3):
  + Mostly bugfixes and backwards compatible D-BUS changes.
* Wed Mar 16 2011 dimstar@opensuse.org
- Update to version 0.8.996 (0.9 beta2):
  + don't require glib 2.26
  + deb#615082, lp#725041: fixes for new dnsmasq
  + crash fixes
  + ifupdown plugin fixes
  + save connection timestamps in /var not /etc
  + install time fixes for Arch Linux
  + libnm-glib crash and correctness fixes
  + fix display of SSIDs in applet tooltips
  + build fixes and cleanups
  + import existing user connections
- Summary from 0.8.995 (0.9 beta1)
  + simpler, easier, more flexible, and cooler applets.
  + Fast User Switching.
  + WiMAX support.
  + System connections by default.
  + More flexible system administration.
  + Scales down to smaller devices.
- Drop patches fixed upstream:
  + nm-64bit-timestamp.diff
  + nm-nis-domain.diff
  + nm-crash-lack-ipv4.patch
  + nm-ignore-temp-files.patch
  + nm-stop-touching-hosts.patch
  + nm-destory-crash.patch
- Add pkgconfig(systemd) BuildRequires for systemd integration
  support.
- Add gobject-introspection-devel BuildRequires to get
  introspection support.
- Pass --disable-wimax to configure for now as we don't have the
  libraries for it.
* Mon Feb 21 2011 binli@opensuse.org
- Add nm-destory-crash.patch, fix crash when NM exit(bnc#673627).
* Tue Feb 15 2011 binli@opensuse.org
- Add the nm-stop-touching-hosts.patch to stop touching /etc/hosts.
  (bnc#667265)
* Wed Feb  2 2011 bjorn.lie@gmail.com
- Added autoreconf since nm-ignore-temp-files.patch needs more
  than touching Makefile.in.
* Sun Jan 30 2011 bjorn.lie@gmail.com 
- Add nm-ignore-temp-files.patch: stop NM from filling dmesg and
  logs by ignoring temporary files (bgo#602868) (bnc#668183)
  Original upstream patch has been extended to also touch
  Makefile.in in order to avoid having to re-bootstrap.
* Fri Jan 14 2011 jeffm@suse.de
- Add nm-crash-lack-ipv4.patch to fix a crash during exit: lack of
  an IPv4 setting indicates DHCP (bnc#664640).
* Tue Dec 14 2010 vuntz@opensuse.org
- Stop removing sr@Latn translation: it was added by
  translation-update-upstream, and the script got fixed now.
* Wed Nov 24 2010 tittiatcoke@gmail.com
- Add patch to fix NM crash (bnc#655685)
* Tue Nov 23 2010 wstephenson@novell.com
- Add patch to fix NM crash with ethernet (bnc#655505)
* Wed Nov 10 2010 coolo@novell.com
- Remove sr@Latn as it's a duplicate of sr@latin and no valid
  locale.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 0.8.2:
  + Native local caching nameserver support using dnsmasq
  + Automatically detect addition and removal of new VPN plugins
  + Support for handling suspend/resume signals from UPower
  + Ensure users are allowed to enable/disable WiFi and networking
  + Ensure WiFi enable state is preserved across reboot and suspend
  + Better handling of /etc/hosts and preservation of custom
    hostnames
  + Support for the systemd session management service
  + Better handling of 'keyfile' system connection errors
  + Support for S390 network devices
  + and much more...
- Split out lang package.
- Pass --with-docs to configure.
* Mon Aug  9 2010 vuntz@opensuse.org
- Change --with-dhcp-client configure option to --with-dhclient.
- Re-enable parallel build.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + Bluetooth Dial-Up Networking
  + nmcli: a command-line interface for controlling NetworkManager
  + Mobile Broadband Status: signal strength, roaming, and access
    technology display
  + Enhanced IPv6 support: including DHCPv6 and tons of fixes
  + Logging and Debugging: make NM as quiet or verbose as you like
- Drop NetworkManager-netconfig-exit-quick.patch, upstreamed.
- Drop NetworkManager-NIS.patch, no longer required.
* Fri Jul 23 2010 bili@novell.com
- nfs script should not use nfs restart(bnc#559021).
* Fri Jul  9 2010 jengelh@medozas.de
- Add SPARC targets to %%files list
- Reword comment about locations of files (since sparcv9 is neither
  single-arch nor a 64-bit environment)
* Wed Jun 30 2010 bili@novell.com
- Update NetworkManager-NIS.patch, init the variable(bnc#618599).
* Tue Jun 29 2010 bili@novell.com
- Add NetworkManager-netconfig-exit-quick.patch, fix wrong return
  value when updating the DNS with netconfig(bnc#595708, bnc#544195,
  bnc#537907, bnc#596163).
* Thu Jun 24 2010 bili@novell.com
- Add NetworkManager-NIS.patch, support NIS domain and servers
  (bnc#608677).
* Tue Jun 15 2010 dimstar@opensuse.org
- Minor spec-cleanup.
* Wed Jun  9 2010 cristian.rodriguez@opensuse.org
- fix NetworkManager dependencies
  * ModemManager and dnsmasq should be recommended, not required
  * should Require iproute2,iputils and ppp
  * Should Recommend iptables
* Wed May 19 2010 lnussel@suse.de
- remove not needed build time dependency on dhcp-client
* Fri Apr 23 2010 bili@novell.com
- Add a general dbus conf file for nm-applet, cnetworkmanager and
  NetworkManager-kde4(bnc#476502).
* Mon Feb 22 2010 dimstar@opensuse.org
- Update to version 0.8:
  + introspection: fix inclusion of Dhcp6Config XML
  + crypto: de-init NSS after calling PR_GetError()
  + ifcfg-rh: read and write DHCPv6 connections
  + policy: fall back to original hostname before trying reverse
    DNS
  + bluetooth: finish DUN implementation
  + introspection: sync device state reason code with
    NetworkManager.h
  + policy: be more selective when adding hostname to /etc/hosts
  + gsm: handle PIN requests during modem enable too
  + system-settings: register setting errors so D-Bus errors are
    meaningful
  + Updated translations.
* Fri Feb 12 2010 vuntz@opensuse.org
- Add NetworkManager-rpmlintrc to list of sources.
- Fix self-obsoletion of dhcdbd.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- Update to version 0.7.999:
  + ifcfg-rh: formatting fix
  + ifcfg-rh: handle missing PREFIX by generating one
  + ifcfg-rh: ensure IPv6 addresses are cleared when none get
    written out
  + ifcfg-rh: add IPv6 addressing and routes support (rh #523288)
  + backends: add backend for Pardus
  + libnm-util: fix NMDeviceBt hardware address property
  + core: ensure failed /etc/hosts update writes out
    well-formatted file (lp#471498)
  + olpc-mesh: fix companion path and active channel property
    types
  + netlink: work around kernel cache refill problems
  + keyfile: add IPv6 support (bgo #593814)
  + libnm-util: add IPv6 comparison functions
  + Translation updates
- Remove 0006-NIS-patch.patch, 0007-Fix-etc-hosts-updating.patch,
  nm-hal-tree-changes.patch and
  0009-Implement-sending-system-hostname-with-DHCP-client.patch.
  These patches were not applied
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to the latest upstream 0.8 branch:
  + Add support for Bluetooth DUN devices.
  + Add support to manually deactivate active devices.
  + Much improved killswitch handling.
  + The state (networking, wireless, ...) is now remembered after
    reboots.
  + The system settings daemon is removed and the main daemon has
    support for distribution specific plugins now.
  + The keyfile plugin supports a lot more data formats now (human
    readable IP addresses, passwords without hashing etc). Add
    back the support for certificate file paths.
  + Add back support for multiple CA certificate per (.PEM) file.
  + HAL usage is replaced with gudev.
  + IPv6 support.
  + Documentation updates.
  + Lots of bug fixes.
* Mon Oct  5 2009 tambet@novell.com
- Never fall back to manually updating resolv.conf, even if
  netconfig fails (bnc #537907, #544195).
* Mon Sep 14 2009 tambet@novell.com
- Fix a segfault introduced by the updated ModemManager patch
  (bnc #538180).
* Wed Aug 26 2009 tambet@novell.com
- HAL added 'ssb' (Silicon Sonics Backplane, used internally on
  most Broadcom ethernet and wifi chipsets) in 0.5.13, which
  changed the device list layout and made NM unable to get the
  driver for the wifi device. Fix that (bnc #526105).
* Tue Aug 25 2009 tambet@novell.com
- Fix issues with root being at_console (bnc #530430).
* Thu Aug 20 2009 aj@suse.de
- Require libiw-devel for building instead of wireless-tools.
* Tue Aug 11 2009 tittiatcoke@gmail.com
- Update to latest 0.7.1 upstream
  + Handle ZTE (Onda) device port types
  + Wait 20 seconds (instead of 15) for PPP connections to come up
  + Block until netconfig exits
  + Allow 63 byte long PSK
  + Fix dbus reconnection
  + Handle unsolicited supplicant scans
  + Other fixes
* Tue Jul 21 2009 aj@suse.de
- Add 0013-iptables-path.patch to correct path for iptables, it lives
  in /usr/sbin.
* Tue Jul 14 2009 tittiatcoke@gmail.com
- Added Build dependency for libuuid
* Wed May 27 2009 tambet@novell.com
- Update to 0.7.1:
  + Plays better with stupid wifi and ethernet drivers.
  + Support for rfc3442 classless static routes.
  + The default "Auto eth0" connection is now read/write.
  + Compatibility fixes for 802.1x PEAP authentication and 3G/PPP
    connections.
  + Reduced wakeups for power saving awesomeness.
  + Ability to deny specific devices the default route.
  + More correct display of wifi signal strength.
  + Custom IPv4 settings for mobile broadband connections.
  + More informative display of network device state.
  + Lots of bugs fixed.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Feb 11 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Thu Jan  8 2009 mauro@suse.de
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Thu Dec  4 2008 tambet@novell.com
- Fix merging the default route (bnc #450553).
* Tue Dec  2 2008 tambet@novell.com
- Rebase from the official NetworkManager 0.7.0 release:
  + Documentation fixes and updates.
  + Updated translations: de, fi, or, sv.
- Fix the /etc/hosts file updating (bnc #433365).
- Fix NIS information updating (bnc #437320).
- Really fix the location of dhclient leases file (bnc #446611).
* Fri Nov 21 2008 tambet@novell.com
- Add support to use distro wide CA certificates from
  /ets/ssl/certs (bnc #436192).
- Unmount NFS shares when network is deactivated (bnc #341647).
- Recomment NetworkManager-client (bnc #445643).
- Fix the location of dhclient leases file (bnc #446611).
- Add support for having certificate filenames in system
  connections.
- Add API reference documentation for libnm-util.
- Handle gateways in different subnets.
- Add support for PKCS#12 certificates (bgo #558982).
- Update translations: es, pl, se
* Fri Nov 14 2008 tambet@novell.com
- Use system CA certificates in case the CA isn't set on connection.
* Mon Nov 10 2008 tambet@suse.de
- Fix the bug where the keyfile system settings plugin would
  return empty strings for passwords when they're not set.
* Fri Nov  7 2008 tambet@suse.de
- Add support for passing through PKCS#11 certificates.
- Monitor /etc/HOSTNAME and set hostname accordingly (bnc #)440809.
* Mon Nov  3 2008 tambet@suse.de
- Break the public API to hide the internal data structures in
  hope to achieve maintainable public API from now on.
* Fri Oct 24 2008 tambet@suse.de
- Fix the problem where NetworkManager thinks it can't start ModemManager.
- Always add really important stuff to the command line to ensure
  that NM overrides /etc/ppp/options (bgo #556781).
- Fix segfaults on shutdown.
- Correctly determine encryption capabilities.
- Add support for VPN subnet gateways (bgo #549196).
- Rework default route handling to consolidate decisions in the policy,
  and to take active VPN connections into account when changing the default
  route (bgo #545912).
- Updated translations: be, es, nb, pt_BR, sv.
* Mon Oct 20 2008 tambet@suse.de
- Implement merging connections from /etc/sysconfig/network in
  nm-opensuse-merge (part of bnc #433084).
* Fri Oct 10 2008 tambet@suse.de
- Update to the latest upstream:
  + Add a 'hostname' dispatcher action triggered on hostname changes
    (bgo #552983).
  + Fix a memory corruption in setting routes.
  + Fix system connections saving after modifications.
  + Fix a system settings crash on removal of ethernet devices.
  + Make PPP username & password handling more robust.
  + Clear secrets on invalid connections.
  + Fix setting value comparison issues.
  + Set route priorities correctly for multiple active devices in the same
    subnet.
  + Handle ipw3945 suspend/resume by retrying the GIWRANGE request a few
    times when it returns EAGAIN (rh #362421).
  + Update translations: es, et, fi, lv, nb, sv.
- NetworkManager always sets full hostname instead of short one (bnc #433179).
- NetworkManager does not require more exact libnl version (bnc #421735).
- NetworkManager: ethtool_cmd now has a speed_hi field to support devices
  faster than 65535 Mb (bnc #431512).
- Fix a bug where during shutdown, NetworkManager messages pollute the
  console (bnc #391747).
- Fix typoes in CDMA device which made them appear as GSM devices
  (bgo #430502).
* Fri Sep 26 2008 tambet@suse.de
- Update to the latest from upstream:
  + Add support for static and dynamic hostnames.
  + Correctly clean wpa_supplicant state on shutdown (bnc #404883).
  + Fix a crash when a device is removed (bgo #549401).
  + Fix (bgo #551361).
  + Updated translations: it br sv lt fi hu fr.
* Thu Sep 25 2008 ro@suse.de
- use autoreconf -f -i for new libtool
* Fri Sep 19 2008 tambet@suse.de
- Update NIS information from a dispatcher script.
- Make it build on 11.0 as well.
- Update to the latest upstream:
  + Default to "all ciphers" for wireless security setting.
  + Fix a problem where unamanaged devices could cause recursive connection reloads.
  + Fix a typo causing crashes in keyfile plugin.
  + Updated translations: cs, fi, fr, nl.
* Mon Sep 15 2008 ro@suse.de
- added directory to filelist
* Sun Sep 14 2008 aj@suse.de
- Fix directory ownership.
- Remove unneeded build require on ppp.
* Fri Sep 12 2008 tambet@suse.de
- Bring up to date with SVN.
- Add patches to remove the built in modem code and use ModemManager
  instead.
- Create a -doc package now that NetworkManager has API reference
  documentation.
* Fri Aug  1 2008 tambet@suse.de
- Bring up to date with SVN again.
* Mon Jun 30 2008 tambet@suse.de
- Bring up to date with SVN again.
* Mon Jun 30 2008 tambet@suse.de
  SWAMP-ID: 18426
- Don't assume DHCP server always returns a gateway (bnc #392598).
- Missing default route in case the gateways is in another subnet (bnc #266215).
- Cannot enter PIN code with some modems (bnc #394731).
- Changes in yast not picked up until reboot (bnc #378802).
- Make sure pppd is shut down, even if it's blockin on reads (bnc #394598).
- Fix a lifetime issue with VPN services (bnc #381769).
* Wed Jun  4 2008 tambet@suse.de
- Fix a bug where NetworkManager does not work at all in case there are
  devices marked with NM_CONTROLLED="no" (bnc #390404).
* Sat May 24 2008 aj@suse.de
- Disable parallel build for now as it let to build failures.
* Fri May 23 2008 tambet@suse.de
- Fix the configuration file path sent to dhclient (bnc #390770).
- Move crypto handling to NetworkManager (from NetworkManager-gnome), implement
  WPA-EAP configuration reading for sysconfig.
- Make the system settings service exit when the bus goes away. (brc #444976).
- If the default gateway is in another subnet, first add route to it, then the
  default route (bnc #266215).
- Optimize waking up after suspend, don't remove all the devices and then add
  everything back. Just syncronize with HAL.
- Close serial devices when not active or activating (bnc #392604 and
  bnc #392605).
- Make it possible to override DNS information returned by DHCP.
* Tue May 13 2008 wstephenson@suse.de
- Fix enum syntax errors in installed headers.
- Fix 99%% CPU bug due to PolKitContext.
* Fri May  9 2008 tambet@suse.de
- Upgrade to the latest SVN:
  Update system settings suse plugin.
  Use PolicyKit to restrict changes to system connections.
  Add Keyfile system settings plugin.
  Allow multiple addresses for devices.
  Use libnl for all ip address and route manipulation.
  Don't require wireless-tools.
  Improve nm-online tool.
* Fri Apr 11 2008 tambet@suse.de
- Upgrade to the latest SVN:
  Automatically create a default connection for wired devices that are not
  configured in /etc/sysconfig.
  Implement ignoring devices that should be ignored by NM according to
  system configuration (Not used on suse yet).
  Internal VPN API rework.
  Lots of love to the libnm-glib.
  Fix DSL (pppoe) authentication.
  Make it build with gcc 4.3.
  Bug fixes.
* Mon Apr  7 2008 maw@suse.de
- The ppp package now installs various modules that NetworkManager
  uses in %%{_libdir}/pppd; adjust to that change.
* Fri Mar 14 2008 tambet@suse.de
- Fix a crasher bug triggered very frequently on waking up from suspend.
* Thu Mar 13 2008 tambet@suse.de
- Upgrade to the latest SVN:
  Implement support for multiple active devices.
  Implement support for DSL (pppoe) connection.
  Lots of public dbus API cleanup.
  Bug fixes.
* Wed Mar 12 2008 tambet@suse.de
- Work with updated HAL (bnc #369539).
* Mon Mar  3 2008 maw@suse.de
- Fix build on biarch systems.
* Fri Feb 29 2008 tambet@suse.de
- Upgrade to the latest SVN.
* Mon Feb 11 2008 coolo@suse.de
- fix pppd installation
* Tue Feb  5 2008 maw@suse.de
- Build with -fno-strict-aliasing.
* Mon Feb  4 2008 tambet@suse.de
- Upgrade to the latest SVN.
- Re-remove some files NM installs, they really aren't ready yet.
* Sat Jan 12 2008 schwab@suse.de
- Fix last change.
* Fri Jan 11 2008 aj@suse.de
- Install nm-tool and nm-online binaries and not
  the libtool wrappers (#353240).
- Add proper provides/obsoletes for dhcdbd.
* Fri Jan 11 2008 dmueller@suse.de
- fix file lists
- fix various specfile / packaging errors
* Wed Nov 28 2007 tambet@suse.de
- Upgrade to the unstable branch (0.7).
  - many changes and bugfixes
  - integrate all previous patches
  - switch to using dhcp-client instead of dhcdbd
  - gnome applet split off to own source
* Fri Sep 14 2007 tambet@suse.de
- Make sure gnome-keyring does not return empty result. (Novell #307910).
* Wed Aug 15 2007 tambet@suse.de
- Fix the hard-coded gnomesu path. (Novell #299518).
* Tue Aug  7 2007 tambet@suse.de
- Fix a crasher bug in nm-applet that was caused by a typo in a manually
  updated patch.
* Fri Aug  3 2007 sbrabec@suse.cz
- Updated gnome-patch-translation support.
* Fri Aug  3 2007 tambet@suse.de
- Update to the latest version from upstream:
    Add support for 2-phase authentication.
    Add support for rfkill switch.
- Add an editor for stored wireless networks.
- Fix the packaging bug where the log file was not owned by the package
    (Novell #280464).
- Fix the issue where NM doesn't honor YaST Static IP Settings
    (Novell #271757).
- Fix the packaging issue to not require gnome-panel (Novell #229291).
* Tue May 15 2007 pgajdos@suse.cz
- removed invalid PreReq: gtk2 >= {%%gtk_version} gnome-icon-theme
- added Requires: gtk2 >= {%%gtk_version}
- removed gnome-icon-theme from BuildRequires [#247450]
* Thu May 10 2007 tambet@suse.de
- Do not overwrite existing AP properties when merging the information from
  /etc/sysconfig/network/. Fixes the problem described in
  https://bugzilla.novell.com/show_bug.cgi?id=255765#c59
* Wed Mar  7 2007 jhargadon@suse.de
- fixed a problem with nm-resolv-conf-header-rml.patch (#249251)
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Tue Feb 13 2007 aj@suse.de
- Fix typo (it should be BuildRequires).
* Fri Feb  9 2007 sbrabec@suse.cz
- Removed remaining references to /opt/gnome (#243824).
- Build with libnotify.
- Spec file cleanup.
* Tue Jan 30 2007 sbrabec@suse.cz
- Changed GNOME prefix to /usr.
* Mon Nov 20 2006 tambet@suse.de
- Add a hack to fix translations (Novell #222329).
* Tue Nov 14 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Sun Nov 12 2006 thoenig@suse.de
- Add patch avahi-dbus-request-name-flags-fix-thoenig-01.patch:
  Fix flawed logic for flags passed to dbus_bus_request_name()
* Fri Nov 10 2006 tambet@suse.de
- Pull in latest CVS updates:
  - Fix a bunch of memory leaks and reference counting issues.
  (Novell #217027).
- Actually fix (Novell #212556).
- Implement disconnect wireless on exit (Novell #218848).
* Thu Nov  2 2006 tambet@suse.de
- Pull in latest CVS updates:
  - Suppress messages from the "SCAN" command.
  - Reduce the number of times the gnome applet wakes up.
  - Add LEAP authentication.
- Fix multiple problems with the fallback patch (Novell #212556):
  - Populate the key information from gconf for fallback keys.
  - Make sure the AP broadcast state isn't lost in case of fallback
  networks.
- Build fixes:
  - Merge all fallback related patches.
  - autoreconf before build to fix intltool issues.
  - Add some auto-detected Requires.
* Fri Oct 20 2006 tambet@suse.de
- Pull in latest CVS update: Don't kill nscd (#149613).
- Add a missing Requires to -devel package.
* Tue Oct 17 2006 tambet@suse.de
- Pull in latest CVS updates:
  - Don't loop infinitely if netmask is 0 (Gnome #352634)
  - Bump vpn timeout to 45s.
  - Backported async scanning patch backported from HEAD.
  - Make renaming a VPN entry work (Novell #193711).
  - Make sleep/wake distinguishable from enable/disable networking
  (Novell #199071).
  - Fix a packaging issue (Novell #212506).
- Add 'fallback' support (Novell #175172).
- Remove nm-dbus-api-fix-thoening-01.path as it's upstream now.
* Mon Sep 25 2006 thoenig@suse.de
- Do not "Require: NetworkManager-client" but "Recommend:
  NetworkManager-client" to avoid circular dependencies.
* Thu Aug 17 2006 rml@suse.de
- Pull in latest CVS updates:
  - Do not restart ypbind, as our ypbind now listens on DBUS
  - Less wpa_supplicant debug spew
  - Better key request logic
  - Fixes for big-endian machines in SHA-1 algorithm
  - Shutdown all VPN connections on logout (Novell #187714)
  - Fix memory leak
- Add libtool and iproute2 to BuildRequires
- Remove patch "nm-debug-wpa-less-rml.patch" as it is now upstream
* Wed Aug  9 2006 thoenig@suse.de
- Add patch: nm-dbus-api-fix-thoenig-01.patch
* Thu Jul 13 2006 rml@suse.de
- Update to NetworkManager 0.6.4
  - Lots of bugfixes
- Drop upstream patches
- Remove libnotify support and drop dependencies
* Wed Jun 28 2006 rml@suse.de
- Translation update
* Tue Jun 20 2006 rml@suse.de
- Put wpa_supplicant into Ad-Hoc mode for all Ad-Hoc networks, not
  just ones that NetworkManager itself creates (Novell bug #186806)
* Mon Jun 19 2006 rml@suse.de
- Fix automatic connection to WPA Enterprise networks (Novell bug
  [#175172])
* Fri Jun 16 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Mon Jun 12 2006 rml@suse.de
- nm-applet: Add nm-dialup-bugfix-183974.patch to fix bug where the
  applet's icon does not reflect dialup state (Novell bug #183974)
* Mon Jun 12 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Fri Jun  9 2006 rml@suse.de
- Add nm-roaming-bugfix-183320.patch to fix bug where a transient
  BSSID change was recorded as roaming (Novell bug #183338)
- nm-applet: Add nm-gconf-bugfix-183337.patch to fix bug where
  reading of booleans from Gconf always failed (Novell bug #183337)
- Add nm-bssid-bugfix-183343.patch to fix bug where NM would merge
  AP objects with zero BSSID values: AP objects should merge only
  when the BSSIDs are both valid and matching (Novell bug #183343)
- Add nm-dsl-bugfix-184031.patch to fix bug where NM was not
  enumerating DSL connections (Novell bug #184031)
* Fri Jun  2 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Tue May 30 2006 rml@suse.de
- Fix crash in disposing of wireless objects before they are fully
  initialized (Novell bug #179525)
- Fix race on startup that prompted twice for wireless information
  (Novell bug #170587)
- nm-vpn-properties: Fix crash with NULL service names (Novell
  bug #179655)
- nm-vpn-properties: Fix option parsing (GNOME bug #33684)
- nm-vpn-properties: UI love (GNOME bug #336913)
- Update translations from GNOME CVS (Novell bug #169096)
- Rename NetworkManager-po-update.patch to nm-po-update.patch
* Mon May 29 2006 sbrabec@suse.cz
- Merged upstream translations from GNOME CVS (#169096#c37).
* Mon May 29 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation (#169096).
* Fri May 26 2006 rml@suse.de
- Make sure we require and correctly build with gcrypt support
  (Novell bug #179315)
* Thu May 25 2006 rml@suse.de
- For ndiswrapper, only use "AP_SCAN 2" if the network is not
  broadcasting (Novell bug #178210)
* Wed May 24 2006 rml@suse.de
- Do not fallback to link-local IP generation on infrastructure
  wireless networks, only Ad-Hoc  (Novell bug #178403)
- Set and use the current locale directory (Novell bug #169096)
- Bump version requirement on wpa_supplicant to 0.4.8-14 from
  0.4.8-9 (Novell bug #175892)
* Mon May 22 2006 rml@suse.de
- Fix ypbind/autofs behavior to never automatically start either,
  but only reload as needed (Novell bug #175935)
- nm-applet: Fix crash on icon-theme change if icons no longer
  exist (Novell bug #177426)
- Fix bug with weirdly-named network interfaces (GNOME bug #330832)
* Fri May 19 2006 ro@suse.de
- fix requirement. sysconfig in sles10 has release 13.3 currently
  (the version in sysconfig should have been fixed instead of
  requiring a release-number ...)
* Thu May 18 2006 rml@suse.de
- Use "AP_SCAN 2" for ipw2200 if the network is hidden (Novell
  bug #176575)
- nm-applet: Update Hungarian translation (Novell bug #158997)
- Bump package requirement on sysconfig to 0.50.9-14 or later
- Make sysconfig a PreReq, not a Requires (Novell bug #176993)
* Wed May 17 2006 rml@suse.de
- Add README.ypbind-autofs, describing the interaction between
  NetworkManager, ypbind, and autofs (Novell bug #175935)
- Automatically populate allowed MAC list from BSSIDs discovered
  via roaming (Novell bug #175172)
- Rediff nm-madwifi-strength-rml.patch
- nm-applet: Differentiate Ad-Hoc networks with unique icon
  (Novell bug #176589)
- Add patch nm-fix-adhoc-icon-rml.patch to workaround bad nm-adhoc
  icon
- Bump package requires on dhcdbd to version 1.12-19 or later
- Bump package requires on dhcp to version to 3.0.3-22 or later
* Tue May 16 2006 rml@suse.de
- Do not touch ypbind or autofs unless the sysconfig option
  dhcp:DHCLIENT_MODIFY_NIS_CONF is set to "yes" (Novell #175935)
* Mon May 15 2006 rml@suse.de
- Look for DHCLIENT_MODIFY_RESOLV_CONF in dhcp, not config (Novell
  bug #175688)
* Wed May 10 2006 rml@suse.de
- Fix double free causing crash on start with some ifcfg-wlan
  configurations (Novell bug #173442)
* Tue May  9 2006 rml@suse.de
- nm-applet: Save WPA EPA private key passhrase, if any, in the
  GNOME keyring and not in gconf (Novell bug #173823)
- Merge nm-online-header.patch into nm-0.6-branch.patch (fix is now
  upstream)
* Sun May  7 2006 jpr@suse.de
- Fix header include to fix build
* Tue May  2 2006 rml@suse.de
- Install nm-online utility (start of fix for Novell bug #169632)
- nm-applet: Don't try to convert blank network names to new-style
  gconf format
- Enable NM by default if installing for the first time (Novell
  bug #169964)
- Write out a YaST-friendly header in resolv.conf (Novell #171488)
- Fix WPA Passphrase entry on big-endian machines (GNOME #336991)
- Enforce sane umask on the daemon (Novell bug #173229)
- Respect dhcp:DHCLIENT_MODIFY_RESOLV_CONF, not
  config:MODIFY_RESOLV_CONF_DYNAMICALLY, when deciding whether to
  write out an updated /etc/resolv.conf (Novell bug #169858)
* Tue Apr 25 2006 rml@suse.de
- Fix "shared/restricted" key mode (Novell bug #168250)
* Fri Apr 21 2006 rml@suse.de
- Use "AP_SCAN 2" for airo_cs, too (Novell bug #168308)
* Thu Apr 20 2006 rml@suse.de
- For ipw2200, use "AP_SCAN 2" if the AP is hidden (166219)
- nm-vpn-properties: Don't let the user open more than one 'Configure
  VPN' window at a time, lest chaos ensue (Novell bug #165011)
- nm-applet: Don't bail out if the timestamp is not set
* Thu Apr 13 2006 rml@suse.de
- Install "nfs" dispatcher.d script to automatically restart NFS
  on interface up (Novell bug #156947)
* Wed Apr 12 2006 jg@suse.de
- Use wpa_supplicant 'wext' backend for ndiswrapper (Novell bug
  [#158892])
* Tue Apr 11 2006 rml@suse.de
- Use "AP_SCAN 2" for ndiswrapper (Novell bug #165315)
- VPN Configure: Don't crash when re-Adding a connection after
  closing window (Novell bug #153085)
* Mon Apr 10 2006 rml@suse.de
- VPN Configure: Don't disable 'Forward' button when entering
  dialog via 'Back' (Novell bug #164895)
* Thu Apr  6 2006 rml@suse.de
- Reflect active modem/ISDN connections in state.  Fixes bug where
  NM would report system as offline even if dial up connection were
  active (Novell bug #161611)
* Tue Apr  4 2006 rml@suse.de
- nm-applet: Remove 'Remove' option from right-click menu (undo
  Novell bug #155690)
* Wed Mar 29 2006 rml@suse.de
- Allow VPN modules to specify a per-route MSS value (bug #157988)
- Fix possible crash in strcmp (Novell bug #162104)
- Have NetworkManager require NetworkManager-client and have
  NetworkManager-gnome provide NetworkManager-client (bug #158326)
* Tue Mar 28 2006 rml@suse.de
- Don't let wpa_supplicant scan with the airo driver (bug #161389)
- Don't let wpa_supplicant scan when creating a new Ad-Hoc network,
  even if using the madwifi driver
- nm-applet: minor HIG-related UI tweaks
* Mon Mar 27 2006 rml@suse.de
- Revert ypbind restart behavior (Novell bug #159070)
- Bump wpa_supplicant requirement to version 0.4.8-9 (Bug #144268)
- Better handle capability detection and connection to EAP networks
- Use "AP_SCAN 2" even for non-broadcast networks (Bug #156970)
- Bump version to 0.6.2
* Sun Mar 26 2006 thoenig@suse.de
- Add unpackaged icons to %%files gnome
* Fri Mar 24 2006 rml@suse.de
- Fix VPN animation (Novell bug #153731)
- Fix minor glitch in wireless strength level icon
- nm-applet: Fix small memory leak in notification display
- libnm-glib.so belongs in -devel, too
- Merge patches nm-always-enable-wpa and nm-supplicant-timeout-rml
  into nm-wireless-driver-workarounds-rml.patch
- Require glib2 in NetworkManager-glib
* Fri Mar 24 2006 dmueller@suse.de
- libnm-util.so belongs in -devel
* Thu Mar 23 2006 rml@suse.de
- Let the applet reconnect to DBUS on restart (Novell bug #150042)
- Set DHCP timeout to 45s (Novell bugs #153243 and #159812)
- Do not override the gtk default invisible character
- Bump dbus-1 requirement to 0.60-22 or later
- Bump dhcdbd requirement to 1.12-9 or later
* Wed Mar 22 2006 rml@suse.de
- Properly handle "Dynamic WEP" (Novell bug #158589)
* Tue Mar 21 2006 rml@suse.de
- Respect and set per-device MTU value in sysconfig, if any (Novell
  bug #159354 and #157737)
* Tue Mar 21 2006 rml@suse.de
- Fix crash in parsing hex keys from sysconfig (Novell #159394)
* Fri Mar 17 2006 rml@suse.de
- Do not restart ypbind on NIS configuration change, just ask it
  to reload its configuration (Novell bug #159070)
- No longer start dhcdbd, but rely on sysconfig to start it before
  it starts NetworkManager, fixing a race (Novell bug #159125)
- Require sysconfig 0.50.7 or later
* Thu Mar 16 2006 rml@suse.de
- Do not run gtk-update-icon-cache in post (Novell bug #158381)
- Rename patch 'nm-configure-modem-item-rml.patch' to
  'nm-configure-networking-rml.patch'
- Add patch 'nm-0.6-branch.patch' to fix behavior in reading static
  wireless configurations from sysconfig
- Don't down devices on suspend (Novell bug #142960 and #156509)
- Merge 'nm-bug-fix-157048-rml.patch' into 'nm-0.6-branch.patch'
* Mon Mar 13 2006 rml@suse.de
- Add 'Configure Networking' option that invokes YaST
* Mon Mar 13 2006 rml@suse.de
- nm-applet: Fix duplicate widgets in 'Add VPN' (Novell
  bug #157048)
- Actually apply 'nm-debug-wpa-less-rml.patch'
* Mon Mar 13 2006 rml@suse.de
- Update to 0.6.1
- Have the dispatcher daemon survive DBUS restarts
- Add patch 'nm-debug-wpa-less-rml.patch'
* Fri Mar 10 2006 rml@suse.de
- Don't let wpa_supplicant log keys, either (Bug #156977)
- Orinoco tweak (Bug #144268)
- nm-applet: add checkbox for un-hiding password entry
* Fri Mar 10 2006 rml@suse.de
- Update to 0.6.0cvs20060310
- Fix WPA Enterprise SEGV on successfull connect (Bug #156973)
- Do not log WPA Enterprise password in clear text (Bug #156977)
* Thu Mar  9 2006 rml@suse.de
- Update to 0.6.0cvs20060309
- Parse sysconfig encryption settings, too
* Wed Mar  8 2006 rml@suse.de
- Update to 0.6.0cvs20060308
- nm-applet: Hide password keystrokes (Novell beta customer)
- Trust wireless networks in sysconfig
* Tue Mar  7 2006 rml@suse.de
- Update to 0.6.0cvs20060307
- nm-applet: Add 'Remove' option to the applet (Novell bug #155690)
* Mon Mar  6 2006 rml@suse.de
- Have NetworkManager.pc provide the NetworkManager include
  directory in CFLAGS.
- Undo prism54 workarounds
- Specifically match against "airo" for the airo driver workaround
- Better logging for dhcdbd events
* Mon Mar  6 2006 rml@suse.de
- Update to 0.6.0cvs20060306
- Workarounds for prism54 wireless driver (Novell bug #148210
  and #144938)
- Workaround for airo wireless driver
- Improved handling of activation cancellation (Novell bug #150787)
* Fri Mar  3 2006 rml@suse.de
- Update to 0.6.0 (just a version bump)
* Fri Mar  3 2006 rml@suse.de
- Update to 0.5.1cvs20060303
- nm-applet and nm-tool: Display per-device speed and per-network
  maximum bitrate (Novell bug #154451)
- Fixes for orinoco_cs driver (Novell bug #144268)
- Fixes for ndiswrapper driver (Novell bug #153536)
- Do not scan-spam the driver on startup
- Replace nm-madwifi-wpa-driver-rml.patch with
  nm-wireless-driver-workarounds-rml.patch
- Misc. cleanup
* Thu Mar  2 2006 rml@suse.de
- Update to 0.5.1cvs20060302
- nm-applet: move autostart file to proper location
- Fix crash on connecting to VPN while already connecting (Novell
  bug #152502)
- Workaround for ndiswrapper wireless problems (Novell bug #153536)
* Tue Feb 28 2006 rml@suse.de
- Update to 0.5.1cvs20060228
- Respect MODIFY_RESOLV_CONF_DYNAMICALLY defined in the file
  /etc/sysconfig/network/config and do not update resolv.conf,
  even if DHCP supplies name servers, if this variable is set to
  "yes" (Novell bug #147703)
- Log wpa_supplicant's responses to /var/log/NetworkManager, too
- Don't prune the wireless network scan list too aggressively
- Misc. WPA Enterprise clean up
* Mon Feb 27 2006 rml@suse.de
- Create pid files in both the NetworkManager and
  NetworkManagerDispatcher daemons
- nm-applet: Remove all gconf keys on VPN removal (Novell #153628)
- nm-applet: Let <ENTER> submit passphrase dialog (Novell #153738)
* Mon Feb 27 2006 rml@suse.de
- Own /opt/gnome/share/NetworkManager/
* Mon Feb 27 2006 rml@suse.de
- Update to 0.5.1cvs20060227
- WPA-Enterprise support! (Bug #134238)
- Remove patches nm-dbus-reconnect-thoenig-03.patch and
  nm-transparent-trayicon.patch, both are now upstream
- Log backtrace on crash
- Updated libnotify notification
* Wed Feb 22 2006 thoenig@suse.de
- Update patch nm-dbus-reconnect-thoenig-03.patch: Take care that
  dhcdbd will get back after we've reconnected to the system bus
  (#150042)
* Wed Feb 22 2006 danw@suse.de
- Add nm-transparent-trayicon.patch to make the tray icon
  pretty under KDE. #135448
* Wed Feb 22 2006 thoenig@suse.de
- Add patch to make NM reconnect to the D-BUS system bus if it
  breaks away (#150042)
* Tue Feb 21 2006 rml@suse.de
- Update to 0.5.1cvs20060221
- Do not stomp on others using the default shared dbus connection
  (Fixes GNOME #326572)
- Add libnotify notifications to nm-applet
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Feb 15 2006 rml@suse.de
- Update to 0.5.1cvs20060215
- Fix VPN GUI dialog when successively editing entries of two
  or more different VPN types (Novell bug #150854)
- Improve debugging output
* Tue Feb 14 2006 rml@suse.de
- Update to 0.5.1cvs20060214
- Fix connecting non-broadcast encrypted networks (blocker #150784)
* Mon Feb 13 2006 rml@suse.de
- Update to 0.5.1cvs20060213
- VPN fixes for Novell VPN
- Fix small memory leak
* Tue Feb  7 2006 rml@suse.de
- Always use "AP_SCAN 1" with wpa_supplicant -- madwifi needs it
* Tue Feb  7 2006 rml@suse.de
- Update to 0.5.1cvs20060207
- Fix off-by-one error that broke some WEP connections (#148646)
* Mon Feb  6 2006 rml@suse.de
- Add back nm-supplicant-timeout-rml.patch when new, larger
  timeout value
* Mon Feb  6 2006 rml@suse.de
- Update to 0.5.1cvs20060206
- Better handling of non-broadcast networks
- Merge half of nm-madwifi-wpa-driver-rml.patch upstream
- Remove nm-supplicant-timeout-rml.patch, merged upstream
* Fri Feb  3 2006 rml@suse.de
- Update to 0.5.1cvs20060203
- Do not log encryption information (per bug #147748)
- Fix memory leak in SUSE backend
* Thu Feb  2 2006 rml@suse.de
- Update to 0.5.1cvs20060202
- Better broadcast networks (better fix for #144622)
- Own /var/run/NetworkManager
- Remove 'ntp' and 'SuSEfirewall' scripts and move to requisite
  packages
- Update API for novellvpn
* Wed Feb  1 2006 rml@suse.de
- Update to 0.5.1cvs20060201
- Remove '--sm-disable' from autostart file via sed
- Add nm-tool(1) man page
- Add nm-madwifi-fixes-rml.patch (Fixes critical bug #144622)
* Tue Jan 31 2006 rml@suse.de
- Update to 0.5.1cvs20060131
- Set "set_ssid " in wpa_supplicant for non-broadcasting networks
- More #138404 fixes
* Mon Jan 30 2006 rml@suse.de
- Update to 0.5.1cvs20060130
- Fixes #144624, half of #134238
- Initial #138404 fix
* Fri Jan 27 2006 rml@suse.de
- Update to 0.5.1cvs20060127
- Fixes #144324
* Thu Jan 26 2006 rml@suse.de
- Update to 0.5.1cvs20060126
- Move all non-GNOME bits out of /opt/gnome
* Wed Jan 25 2006 rml@suse.de
- Update to 0.5.1cvs20060125
- Remove temporary patch nm-dhcp-hostname-byte-array-thoenig-01,
  merged upstream
- Add nm-fix-madwifi-strength-rml.patch, fixing strength output of
  Atheros devices
- Update BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 thoenig@suse.de
- temporary patch nm-dhcp-hostname-byte-array-thoenig-01.patch to
  solve #145273
* Mon Jan 23 2006 rml@suse.de
- Require libgnomesu in NetworkManager-gnome
- Add ISDN Configuration menu item, too (Fixes #140756-ng)
- Respect DHCLIENT_SET_HOSTNAME (Fixes #144324)
* Mon Jan 23 2006 rml@suse.de
- Update to 0.5.1cvs20060123
- Move daemons to /usr/sbin from /usr/bin (Fixes #144033)
- Spec file tweaks
* Thu Jan 19 2006 rml@suse.de
- Update to 0.5.1cvs20060119
- Respect NM_CONTROLLED flag in sysconfig
* Wed Jan 18 2006 rml@suse.de
- Update to 0.5.1cvs20060118
- Fixes #143725
- Add nm-never-restart-nm-applet-rml-1.patch
- Remove no-longer-needed insserv calls
- Move ldconfig run from preun to postun
- Misc. spec file cleanup
* Tue Jan 17 2006 rml@suse.de
- Update to 0.5.1cvs20060117
- Fixes #143496
* Mon Jan 16 2006 rml@suse.de
- Update to 0.5.1cvs20060116
- Fixes #135595
- C++-sanitizes headers for thoenig
* Fri Jan 13 2006 rml@suse.de
- Update to 0.5.1cvs20060113
* Thu Jan 12 2006 rml@suse.de
- Fix Novell #142773.
* Thu Jan 12 2006 rml@suse.de
- Update to 0.5.1cvs20060112
- Adds WPA-1 and WPA-2 support (fixes bug #134238)
* Mon Jan  9 2006 rml@suse.de
- Update to 0.5.1cvs20060107
* Mon Jan  9 2006 ro@suse.de
- remove ExcludeArch
* Fri Jan  6 2006 rml@suse.de
- Update to 0.5.1cvs20060106
- Fix #140733 and 140756, maybe fix #139300
* Wed Jan  4 2006 rml@suse.de
- Update to 0.5.1cvs20060104
- Redo kernel header patch
* Tue Dec 20 2005 ro@suse.de
- fix build by avoiding some more kernel headers
* Mon Dec 19 2005 rml@suse.de
- Update nm-applet.desktop
* Mon Dec 19 2005 rml@suse.de
- Update Requires
* Fri Dec 16 2005 rml@suse.de
- Add SuSEfirewall script to dispatcher.d to recycle firewall
  on interface change (per aj).
* Wed Dec 14 2005 rml@suse.de
- Write out header on resolv.conf (fixes #137762)
- Force nm-applet.desktop permissions
* Mon Dec 12 2005 rml@suse.de
- Update to 0.5.1cvs20051212 (fixes #134369)
- Add libnm-util packages
* Fri Dec  9 2005 rml@suse.de
- Update to 0.5.1cvs20051209
- Add Tango icons
* Thu Dec  8 2005 rml@suse.de
- Update to 0.5.1cvs20051208
- Add networkmanager-dispatcher initscript and start it
* Wed Dec  7 2005 rml@suse.de
- Update to 0.5.1cvs20051207
- Fixes b.n.c bug #94552
- Add NetworkManagerVPN.h file to devel subpackage
* Thu Dec  1 2005 rml@suse.de
- Update to 0.5.1cvs20051201.  Fixes b.n.o #134178.
* Tue Nov 22 2005 rodrigo@suse.de
- Added autostart file for nm-applet.
* Mon Nov 14 2005 rml@suse.de
- Update to CVS snapshot 20051114
* Mon Nov  7 2005 thoenig@suse.de
- removed 'Conflicts: dhcpcd'
* Fri Nov  4 2005 rml@suse.de
- Update to CVS snapshot 20051104
- gnome-keyring 0.4.4 is fine
* Wed Nov  2 2005 rml@suse.de
- Update to CVS snapshot 20051102 (fixes Novell bug #130041).
- Add patch nm-logarithmic-quality.patch
- Require libnl
- BuildRequire libnl, libnl-devel
* Fri Oct 28 2005 rml@suse.de
- Move gnome-keyring requirement to -gnome subpackage.
* Thu Oct 27 2005 rml@suse.de
- Require gnome-keyring.
* Tue Oct 25 2005 thoenig@suse.de
- fixed duplicated '-p $RPM_BUILD_ROOT%%{_sbindir}' in spec file
* Tue Oct 25 2005 thoenig@suse.de
- added symlink
  /usr/sbin/rcnetworkmanager -> /etc/init.d/networkmanager
* Wed Oct 19 2005 rml@suse.de
- Version 0.5.1
- Update to CVS snapshot 20051019-
* Thu Oct  6 2005 rml@suse.de
- Update to CVS snapshot 20051004.
* Thu Sep 29 2005 thoenig@suse.de
- nm-configure-modems-item-rml-1.patch: added absolute path for
  invocation of gnomesu
* Tue Sep  6 2005 rml@suse.de
- Fix bug #114803, crasher.
* Mon Aug 22 2005 gekker@suse.de
- Update to version 0.4cvs20050805 which fixes bug #105355.
* Fri Aug  5 2005 gekker@suse.de
- Update to version 0.4cvs20050805
- Fixes modem support
* Mon Jul 25 2005 kasievers@suse.de
- New version 0.4cvs20050725
* Wed Jul 20 2005 jpr@suse.de
- Build against dbus 0.35
* Thu Jun 30 2005 gekker@suse.de
- Upate to version 0.4cvs20050630
- Update patch for connection dialog
- Remove patched NetworkManager.conf source
* Wed Jun 29 2005 gekker@suse.de
- Fix DHCDBD_BINARY_PATH
* Tue Jun 28 2005 gekker@suse.de
- update to 0.4cvs20050628
- add suspend/resume support
- add powersave to nfb
- change Requires for rml
* Fri Jun 24 2005 ro@suse.de
- update to 0.4cvs20050617
* Thu Jun 23 2005 ro@suse.de
- search for dhcdbd also in /usr/sbin
* Mon Jun 20 2005 hare@suse.de
- Initial checkin for autobuild.
